# 3rd-Party Software for [freckles](https://freckles.io)

The following 3rd-party software components may be used by or distributed with **freckles**.  This document was automatically generated by [FOSSA](http://fossa.io) on 06/19/19; any information relevant to third-party vendors listed below are collected using common, reasonable means.



## Direct Dependencies


Library|Licenses
-------|--------
**[arrow (0.13.2)](#arrow)**|Apache-2.0
**[asn1crypto (0.24.0)](#asn1crypto)**|MIT
**[binaryornot (0.4.4)](#binaryornot)**|BSD-3-Clause
**[blessings (1.7)](#blessings)**|MIT
**[Cerberus (1.3.1)](#Cerberus)**|MIT
**[certifi (2019.3.9)](#certifi)**|MPL-2.0
**[cffi (1.12.3)](#cffi)**|MIT
**[chardet (3.0.4)](#chardet)**|LGPL-2.1-only
**[click (7.0)](#click)**|BSD-3-Clause
**[click-completion (0.5.0)](#click-completion)**|MIT
**[click-log (0.3.2)](#click-log)**|MIT
**[colorama (0.3.9)](#colorama)**|BSD-2-Clause
**[cookiecutter (1.6.0)](#cookiecutter)**|BSD-3-Clause
**[cryptography (2.6.1)](#cryptography)**|
**[cursor (1.2.0)](#cursor)**|CC-BY-SA-2.5
**[decorator (4.4.0)](#decorator)**|BSD-3-Clause
**[dogpile.cache (0.7.1)](#dogpile.cache)**|BSD-2-Clause
**[exodus-bundler (2.0.2)](#exodus-bundler)**|BSD-3-Clause, BSD-2-Clause
**[future (0.17.1)](#future)**|MIT
**[halo (0.0.26)](#halo)**|MIT
**[idna (2.8)](#idna)**|BSD-3-Clause, **Multi-license:** BSD-3-Clause *OR* Python-2.0
**[Jinja2 (2.10.1)](#Jinja2)**|BSD-3-Clause
**[jinja2-time (0.2.0)](#jinja2-time)**|MIT
**[log-symbols (0.0.13)](#log-symbols)**|MIT
**[Markdown (3.1.1)](#Markdown)**|BSD-3-Clause
**[MarkupSafe (1.1.1)](#MarkupSafe)**|BSD-3-Clause
**[mdv (1.7.4)](#mdv)**|BSD-3-Clause
**[passlib (1.7.1)](#passlib)**|MIT, BSD-3-Clause
**[pbr (5.2.0)](#pbr)**|Apache-2.0
**[plumbum (1.6.7)](#plumbum)**|MIT
**[poyo (0.4.2)](#poyo)**|MIT
**[pp-ez (0.2.0)](#pp-ez)**|BSD-3-Clause
**[pprintpp (0.4.0)](#pprintpp)**|BSD-3-Clause, BSD-2-Clause
**[pycparser (2.19)](#pycparser)**|BSD-3-Clause
**[Pygments (2.4.1)](#Pygments)**|BSD-2-Clause
**[pymdown-extensions (6.0)](#pymdown-extensions)**|**Multi-license:** MIT *OR* BSD-3-Clause, MIT
**[pyOpenSSL (19.0.0)](#pyOpenSSL)**|Apache-2.0
**[python-dateutil (2.8.0)](#python-dateutil)**|**Multi-license:** BSD-3-Clause *OR* Apache-2.0
**[python-slugify (3.0.2)](#python-slugify)**|MIT
**[requests (2.22.0)](#requests)**|Apache-2.0
**[ruamel.yaml (0.15.96)](#ruamel.yaml)**|MIT
**[ruamel.yaml.jinja2 (0.2.2)](#ruamel.yaml.jinja2)**|MIT
**[shellingham (1.3.1)](#shellingham)**|MIT
**[six (1.12.0)](#six)**|MIT
**[spinners (0.0.23)](#spinners)**|MIT
**[stevedore (1.30.1)](#stevedore)**|Apache-2.0
**[tabulate (0.8.3)](#tabulate)**|MIT
**[termcolor (1.1.0)](#termcolor)**|MIT
**[text-unidecode (1.2)](#text-unidecode)**|**Multi-license:** Artistic-1.0 *OR* Artistic-2.0
**[toml (0.10.0)](#toml)**|MIT
**[tqdm (4.32.1)](#tqdm)**|**Multi-license:** MIT *OR* MPL-2.0
**[treelib (1.5.5)](#treelib)**|Apache-2.0, **Multi-license:** Apache-2.0 *OR* Python-2.0
**[urllib3 (1.25.3)](#urllib3)**|MIT
**[whichcraft (0.5.2)](#whichcraft)**|BSD-3-Clause




### Details


#### **arrow (0.13.2)**


* Licenses
    * Apache-2.0
        * Attribution:
        Copyright 2013 Chris Smith

		   Licensed under the Apache License, Version 2.0 (the "License");
		   you may not use this file except in compliance with the License.
		   You may obtain a copy of the License at

		       http://www.apache.org/licenses/LICENSE-2.0

		   Unless required by applicable law or agreed to in writing, software
		   distributed under the License is distributed on an "AS IS" BASIS,
		   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
		   See the License for the specific language governing permissions and
		   limitations under the License.



* Authors
    * [crsmithdev@gmail.com](author)



* Other Licenses



* Project URL
    https://github.com/crsmithdev/arrow/


---
---

#### **asn1crypto (0.24.0)**


* Licenses
    * MIT
        * Attribution:
        Copyright (c) 2019, asn1crypto Contributors
		Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
		The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


* Authors
    * [will@wbond.net](author)



* Other Licenses



* Project URL
    https://github.com/wbond/asn1crypto


---
---

#### **binaryornot (0.4.4)**


* Licenses
    * BSD-3-Clause
        * Attribution:
        Copyright (c) 2013, Audrey Roy
		All rights reserved.

		Redistribution and use in source and binary forms, with or without
		modification, are permitted provided that the following conditions are met:

		\* Redistributions of source code must retain the above copyright notice, this
		  list of conditions and the following disclaimer.

		\* Redistributions in binary form must reproduce the above copyright notice,
		  this list of conditions and the following disclaimer in the documentation
		  and/or other materials provided with the distribution.

		\* Neither the name of BinaryOrNot nor the names of its contributors may be used
		  to endorse or promote products derived from this software without specific
		  prior written permission.

		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
		ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
		WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
		DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
		FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
		DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
		SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
		CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
		OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
		OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.



* Authors
    * [aroy@alum.mit.edu](author)



* Other Licenses



* Project URL
    https://github.com/audreyr/binaryornot


---
---

#### **blessings (1.7)**


* Licenses
    * MIT
        * Attribution:
        Copyright (c) 2011 Erik Rose

		Permission is hereby granted, free of charge, to any person obtaining a copy of
		this software and associated documentation files (the "Software"), to deal in
		the Software without restriction, including without limitation the rights to
		use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
		of the Software, and to permit persons to whom the Software is furnished to do
		so, subject to the following conditions:

		The above copyright notice and this permission notice shall be included in all
		copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
		SOFTWARE.



* Authors
    * [erikrose@grinchcentral.com](author)



* Other Licenses



* Project URL
    https://github.com/erikrose/blessings


---
---

#### **Cerberus (1.3.1)**


* Licenses
    * MIT
        * Attribution:
        ISC License

		Copyright (c) 2012-2016 Nicola Iarocci.

		Permission to use, copy, modify, and/or distribute this software for any
		purpose with or without fee is hereby granted, provided that the above
		copyright notice and this permission notice appear in all copies.

		THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
		REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
		FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
		INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
		LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
		OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
		PERFORMANCE OF THIS SOFTWARE.



* Authors
    * [nicola@nicolaiarocci.com](author)



* Other Licenses
    * ISC



* Project URL
    http://github.com/pyeve/cerberus


---
---

#### **certifi (2019.3.9)**


* Licenses
    * MPL-2.0
        * Attribution:
        This packge contains a modified version of ca-bundle.crt:

		ca-bundle.crt -- Bundle of CA Root Certificates

		Certificate data from Mozilla as of: Thu Nov  3 19:04:19 2011#
		This is a bundle of X.509 certificates of public Certificate Authorities
		(CA). These were automatically extracted from Mozilla's root certificates
		file (certdata.txt).  This file can be found in the mozilla source tree:
		http://mxr.mozilla.org/mozilla/source/security/nss/lib/ckfw/builtins/certdata.txt?raw=1#
		It contains the certificates in PEM format and therefore
		can be directly used with curl / libcurl / php_curl, or with
		an Apache+mod_ssl webserver for SSL client authentication.
		Just configure this file as the SSLCACertificateFile.#

		***** BEGIN LICENSE BLOCK *****
		This Source Code Form is subject to the terms of the Mozilla Public License,
		v. 2.0. If a copy of the MPL was not distributed with this file, You can obtain
		one at http://mozilla.org/MPL/2.0/.

		***** END LICENSE BLOCK *****
		@(#) $RCSfile: certdata.txt,v $ $Revision: 1.80 $ $Date: 2011/11/03 15:11:58 $



* Authors
    * [me@kennethreitz.com](author)



* Other Licenses



* Project URL
    http://certifi.io/


---
---

#### **cffi (1.12.3)**


* Licenses
    * MIT
        * Attribution:

		Except when otherwise stated (look for LICENSE files in directories or
		information at the beginning of each file) all software and
		documentation is licensed as follows:

		    The MIT License

		    Permission is hereby granted, free of charge, to any person
		    obtaining a copy of this software and associated documentation
		    files (the "Software"), to deal in the Software without
		    restriction, including without limitation the rights to use,
		    copy, modify, merge, publish, distribute, sublicense, and/or
		    sell copies of the Software, and to permit persons to whom the
		    Software is furnished to do so, subject to the following conditions:

		    The above copyright notice and this permission notice shall be included
		    in all copies or substantial portions of the Software.

		    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
		    OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
		    THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
		    FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
		    DEALINGS IN THE SOFTWARE.




* Authors
    * [python-cffi@googlegroups.com](author)



* Other Licenses



* Project URL
    http://cffi.readthedocs.org


---
---

#### **chardet (3.0.4)**


* Licenses
    * LGPL-2.1-only
        * Attribution:
        		  GNU LESSER GENERAL PUBLIC LICENSE
				       Version 2.1, February 1999

		 Copyright (C) 1991, 1999 Free Software Foundation, Inc.
		     51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
		 Everyone is permitted to copy and distribute verbatim copies
		 of this license document, but changing it is not allowed.

		[This is the first released version of the Lesser GPL.  It also counts
		 as the successor of the GNU Library Public License, version 2, hence
		 the version number 2.1.]

					    Preamble

		  The licenses for most software are designed to take away your
		freedom to share and change it.  By contrast, the GNU General Public
		Licenses are intended to guarantee your freedom to share and change
		free software--to make sure the software is free for all its users.

		  This license, the Lesser General Public License, applies to some
		specially designated software packages--typically libraries--of the
		Free Software Foundation and other authors who decide to use it.  You
		can use it too, but we suggest you first think carefully about whether
		this license or the ordinary General Public License is the better
		strategy to use in any particular case, based on the explanations below.

		  When we speak of free software, we are referring to freedom of use,
		not price.  Our General Public Licenses are designed to make sure that
		you have the freedom to distribute copies of free software (and charge
		for this service if you wish); that you receive source code or can get
		it if you want it; that you can change the software and use pieces of
		it in new free programs; and that you are informed that you can do
		these things.

		  To protect your rights, we need to make restrictions that forbid
		distributors to deny you these rights or to ask you to surrender these
		rights.  These restrictions translate to certain responsibilities for
		you if you distribute copies of the library or if you modify it.

		  For example, if you distribute copies of the library, whether gratis
		or for a fee, you must give the recipients all the rights that we gave
		you.  You must make sure that they, too, receive or can get the source
		code.  If you link other code with the library, you must provide
		complete object files to the recipients, so that they can relink them
		with the library after making changes to the library and recompiling
		it.  And you must show them these terms so they know their rights.

		  We protect your rights with a two-step method: (1) we copyright the
		library, and (2) we offer you this license, which gives you legal
		permission to copy, distribute and/or modify the library.

		  To protect each distributor, we want to make it very clear that
		there is no warranty for the free library.  Also, if the library is
		modified by someone else and passed on, the recipients should know
		that what they have is not the original version, so that the original
		author's reputation will not be affected by problems that might be
		introduced by others.

		  Finally, software patents pose a constant threat to the existence of
		any free program.  We wish to make sure that a company cannot
		effectively restrict the users of a free program by obtaining a
		restrictive license from a patent holder.  Therefore, we insist that
		any patent license obtained for a version of the library must be
		consistent with the full freedom of use specified in this license.

		  Most GNU software, including some libraries, is covered by the
		ordinary GNU General Public License.  This license, the GNU Lesser
		General Public License, applies to certain designated libraries, and
		is quite different from the ordinary General Public License.  We use
		this license for certain libraries in order to permit linking those
		libraries into non-free programs.

		  When a program is linked with a library, whether statically or using
		a shared library, the combination of the two is legally speaking a
		combined work, a derivative of the original library.  The ordinary
		General Public License therefore permits such linking only if the
		entire combination fits its criteria of freedom.  The Lesser General
		Public License permits more lax criteria for linking other code with
		the library.

		  We call this license the "Lesser" General Public License because it
		does Less to protect the user's freedom than the ordinary General
		Public License.  It also provides other free software developers Less
		of an advantage over competing non-free programs.  These disadvantages
		are the reason we use the ordinary General Public License for many
		libraries.  However, the Lesser license provides advantages in certain
		special circumstances.

		  For example, on rare occasions, there may be a special need to
		encourage the widest possible use of a certain library, so that it becomes
		a de-facto standard.  To achieve this, non-free programs must be
		allowed to use the library.  A more frequent case is that a free
		library does the same job as widely used non-free libraries.  In this
		case, there is little to gain by limiting the free library to free
		software only, so we use the Lesser General Public License.

		  In other cases, permission to use a particular library in non-free
		programs enables a greater number of people to use a large body of
		free software.  For example, permission to use the GNU C Library in
		non-free programs enables many more people to use the whole GNU
		operating system, as well as its variant, the GNU/Linux operating
		system.

		  Although the Lesser General Public License is Less protective of the
		users' freedom, it does ensure that the user of a program that is
		linked with the Library has the freedom and the wherewithal to run
		that program using a modified version of the Library.

		  The precise terms and conditions for copying, distribution and
		modification follow.  Pay close attention to the difference between a
		"work based on the library" and a "work that uses the library".  The
		former contains code derived from the library, whereas the latter must
		be combined with the library in order to run.

				  GNU LESSER GENERAL PUBLIC LICENSE
		   TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION

		  0. This License Agreement applies to any software library or other
		program which contains a notice placed by the copyright holder or
		other authorized party saying it may be distributed under the terms of
		this Lesser General Public License (also called "this License").
		Each licensee is addressed as "you".

		  A "library" means a collection of software functions and/or data
		prepared so as to be conveniently linked with application programs
		(which use some of those functions and data) to form executables.

		  The "Library", below, refers to any such software library or work
		which has been distributed under these terms.  A "work based on the
		Library" means either the Library or any derivative work under
		copyright law: that is to say, a work containing the Library or a
		portion of it, either verbatim or with modifications and/or translated
		straightforwardly into another language.  (Hereinafter, translation is
		included without limitation in the term "modification".)

		  "Source code" for a work means the preferred form of the work for
		making modifications to it.  For a library, complete source code means
		all the source code for all modules it contains, plus any associated
		interface definition files, plus the scripts used to control compilation
		and installation of the library.

		  Activities other than copying, distribution and modification are not
		covered by this License; they are outside its scope.  The act of
		running a program using the Library is not restricted, and output from
		such a program is covered only if its contents constitute a work based
		on the Library (independent of the use of the Library in a tool for
		writing it).  Whether that is true depends on what the Library does
		and what the program that uses the Library does.

		  1. You may copy and distribute verbatim copies of the Library's
		complete source code as you receive it, in any medium, provided that
		you conspicuously and appropriately publish on each copy an
		appropriate copyright notice and disclaimer of warranty; keep intact
		all the notices that refer to this License and to the absence of any
		warranty; and distribute a copy of this License along with the
		Library.

		  You may charge a fee for the physical act of transferring a copy,
		and you may at your option offer warranty protection in exchange for a
		fee.

		  2. You may modify your copy or copies of the Library or any portion
		of it, thus forming a work based on the Library, and copy and
		distribute such modifications or work under the terms of Section 1
		above, provided that you also meet all of these conditions:

		    a) The modified work must itself be a software library.

		    b) You must cause the files modified to carry prominent notices
		    stating that you changed the files and the date of any change.

		    c) You must cause the whole of the work to be licensed at no
		    charge to all third parties under the terms of this License.

		    d) If a facility in the modified Library refers to a function or a
		    table of data to be supplied by an application program that uses
		    the facility, other than as an argument passed when the facility
		    is invoked, then you must make a good faith effort to ensure that,
		    in the event an application does not supply such function or
		    table, the facility still operates, and performs whatever part of
		    its purpose remains meaningful.

		    (For example, a function in a library to compute square roots has
		    a purpose that is entirely well-defined independent of the
		    application.  Therefore, Subsection 2d requires that any
		    application-supplied function or table used by this function must
		    be optional: if the application does not supply it, the square
		    root function must still compute square roots.)

		These requirements apply to the modified work as a whole.  If
		identifiable sections of that work are not derived from the Library,
		and can be reasonably considered independent and separate works in
		themselves, then this License, and its terms, do not apply to those
		sections when you distribute them as separate works.  But when you
		distribute the same sections as part of a whole which is a work based
		on the Library, the distribution of the whole must be on the terms of
		this License, whose permissions for other licensees extend to the
		entire whole, and thus to each and every part regardless of who wrote
		it.

		Thus, it is not the intent of this section to claim rights or contest
		your rights to work written entirely by you; rather, the intent is to
		exercise the right to control the distribution of derivative or
		collective works based on the Library.

		In addition, mere aggregation of another work not based on the Library
		with the Library (or with a work based on the Library) on a volume of
		a storage or distribution medium does not bring the other work under
		the scope of this License.

		  3. You may opt to apply the terms of the ordinary GNU General Public
		License instead of this License to a given copy of the Library.  To do
		this, you must alter all the notices that refer to this License, so
		that they refer to the ordinary GNU General Public License, version 2,
		instead of to this License.  (If a newer version than version 2 of the
		ordinary GNU General Public License has appeared, then you can specify
		that version instead if you wish.)  Do not make any other change in
		these notices.

		  Once this change is made in a given copy, it is irreversible for
		that copy, so the ordinary GNU General Public License applies to all
		subsequent copies and derivative works made from that copy.

		  This option is useful when you wish to copy part of the code of
		the Library into a program that is not a library.

		  4. You may copy and distribute the Library (or a portion or
		derivative of it, under Section 2) in object code or executable form
		under the terms of Sections 1 and 2 above provided that you accompany
		it with the complete corresponding machine-readable source code, which
		must be distributed under the terms of Sections 1 and 2 above on a
		medium customarily used for software interchange.

		  If distribution of object code is made by offering access to copy
		from a designated place, then offering equivalent access to copy the
		source code from the same place satisfies the requirement to
		distribute the source code, even though third parties are not
		compelled to copy the source along with the object code.

		  5. A program that contains no derivative of any portion of the
		Library, but is designed to work with the Library by being compiled or
		linked with it, is called a "work that uses the Library".  Such a
		work, in isolation, is not a derivative work of the Library, and
		therefore falls outside the scope of this License.

		  However, linking a "work that uses the Library" with the Library
		creates an executable that is a derivative of the Library (because it
		contains portions of the Library), rather than a "work that uses the
		library".  The executable is therefore covered by this License.
		Section 6 states terms for distribution of such executables.

		  When a "work that uses the Library" uses material from a header file
		that is part of the Library, the object code for the work may be a
		derivative work of the Library even though the source code is not.
		Whether this is true is especially significant if the work can be
		linked without the Library, or if the work is itself a library.  The
		threshold for this to be true is not precisely defined by law.

		  If such an object file uses only numerical parameters, data
		structure layouts and accessors, and small macros and small inline
		functions (ten lines or less in length), then the use of the object
		file is unrestricted, regardless of whether it is legally a derivative
		work.  (Executables containing this object code plus portions of the
		Library will still fall under Section 6.)

		  Otherwise, if the work is a derivative of the Library, you may
		distribute the object code for the work under the terms of Section 6.
		Any executables containing that work also fall under Section 6,
		whether or not they are linked directly with the Library itself.

		  6. As an exception to the Sections above, you may also combine or
		link a "work that uses the Library" with the Library to produce a
		work containing portions of the Library, and distribute that work
		under terms of your choice, provided that the terms permit
		modification of the work for the customer's own use and reverse
		engineering for debugging such modifications.

		  You must give prominent notice with each copy of the work that the
		Library is used in it and that the Library and its use are covered by
		this License.  You must supply a copy of this License.  If the work
		during execution displays copyright notices, you must include the
		copyright notice for the Library among them, as well as a reference
		directing the user to the copy of this License.  Also, you must do one
		of these things:

		    a) Accompany the work with the complete corresponding
		    machine-readable source code for the Library including whatever
		    changes were used in the work (which must be distributed under
		    Sections 1 and 2 above); and, if the work is an executable linked
		    with the Library, with the complete machine-readable "work that
		    uses the Library", as object code and/or source code, so that the
		    user can modify the Library and then relink to produce a modified
		    executable containing the modified Library.  (It is understood
		    that the user who changes the contents of definitions files in the
		    Library will not necessarily be able to recompile the application
		    to use the modified definitions.)

		    b) Use a suitable shared library mechanism for linking with the
		    Library.  A suitable mechanism is one that (1) uses at run time a
		    copy of the library already present on the user's computer system,
		    rather than copying library functions into the executable, and (2)
		    will operate properly with a modified version of the library, if
		    the user installs one, as long as the modified version is
		    interface-compatible with the version that the work was made with.

		    c) Accompany the work with a written offer, valid for at
		    least three years, to give the same user the materials
		    specified in Subsection 6a, above, for a charge no more
		    than the cost of performing this distribution.

		    d) If distribution of the work is made by offering access to copy
		    from a designated place, offer equivalent access to copy the above
		    specified materials from the same place.

		    e) Verify that the user has already received a copy of these
		    materials or that you have already sent this user a copy.

		  For an executable, the required form of the "work that uses the
		Library" must include any data and utility programs needed for
		reproducing the executable from it.  However, as a special exception,
		the materials to be distributed need not include anything that is
		normally distributed (in either source or binary form) with the major
		components (compiler, kernel, and so on) of the operating system on
		which the executable runs, unless that component itself accompanies
		the executable.

		  It may happen that this requirement contradicts the license
		restrictions of other proprietary libraries that do not normally
		accompany the operating system.  Such a contradiction means you cannot
		use both them and the Library together in an executable that you
		distribute.

		  7. You may place library facilities that are a work based on the
		Library side-by-side in a single library together with other library
		facilities not covered by this License, and distribute such a combined
		library, provided that the separate distribution of the work based on
		the Library and of the other library facilities is otherwise
		permitted, and provided that you do these two things:

		    a) Accompany the combined library with a copy of the same work
		    based on the Library, uncombined with any other library
		    facilities.  This must be distributed under the terms of the
		    Sections above.

		    b) Give prominent notice with the combined library of the fact
		    that part of it is a work based on the Library, and explaining
		    where to find the accompanying uncombined form of the same work.

		  8. You may not copy, modify, sublicense, link with, or distribute
		the Library except as expressly provided under this License.  Any
		attempt otherwise to copy, modify, sublicense, link with, or
		distribute the Library is void, and will automatically terminate your
		rights under this License.  However, parties who have received copies,
		or rights, from you under this License will not have their licenses
		terminated so long as such parties remain in full compliance.

		  9. You are not required to accept this License, since you have not
		signed it.  However, nothing else grants you permission to modify or
		distribute the Library or its derivative works.  These actions are
		prohibited by law if you do not accept this License.  Therefore, by
		modifying or distributing the Library (or any work based on the
		Library), you indicate your acceptance of this License to do so, and
		all its terms and conditions for copying, distributing or modifying
		the Library or works based on it.

		  10. Each time you redistribute the Library (or any work based on the
		Library), the recipient automatically receives a license from the
		original licensor to copy, distribute, link with or modify the Library
		subject to these terms and conditions.  You may not impose any further
		restrictions on the recipients' exercise of the rights granted herein.
		You are not responsible for enforcing compliance by third parties with
		this License.

		  11. If, as a consequence of a court judgment or allegation of patent
		infringement or for any other reason (not limited to patent issues),
		conditions are imposed on you (whether by court order, agreement or
		otherwise) that contradict the conditions of this License, they do not
		excuse you from the conditions of this License.  If you cannot
		distribute so as to satisfy simultaneously your obligations under this
		License and any other pertinent obligations, then as a consequence you
		may not distribute the Library at all.  For example, if a patent
		license would not permit royalty-free redistribution of the Library by
		all those who receive copies directly or indirectly through you, then
		the only way you could satisfy both it and this License would be to
		refrain entirely from distribution of the Library.

		If any portion of this section is held invalid or unenforceable under any
		particular circumstance, the balance of the section is intended to apply,
		and the section as a whole is intended to apply in other circumstances.

		It is not the purpose of this section to induce you to infringe any
		patents or other property right claims or to contest validity of any
		such claims; this section has the sole purpose of protecting the
		integrity of the free software distribution system which is
		implemented by public license practices.  Many people have made
		generous contributions to the wide range of software distributed
		through that system in reliance on consistent application of that
		system; it is up to the author/donor to decide if he or she is willing
		to distribute software through any other system and a licensee cannot
		impose that choice.

		This section is intended to make thoroughly clear what is believed to
		be a consequence of the rest of this License.

		  12. If the distribution and/or use of the Library is restricted in
		certain countries either by patents or by copyrighted interfaces, the
		original copyright holder who places the Library under this License may add
		an explicit geographical distribution limitation excluding those countries,
		so that distribution is permitted only in or among countries not thus
		excluded.  In such case, this License incorporates the limitation as if
		written in the body of this License.

		  13. The Free Software Foundation may publish revised and/or new
		versions of the Lesser General Public License from time to time.
		Such new versions will be similar in spirit to the present version,
		but may differ in detail to address new problems or concerns.

		Each version is given a distinguishing version number.  If the Library
		specifies a version number of this License which applies to it and
		"any later version", you have the option of following the terms and
		conditions either of that version or of any later version published by
		the Free Software Foundation.  If the Library does not specify a
		license version number, you may choose any version ever published by
		the Free Software Foundation.

		  14. If you wish to incorporate parts of the Library into other free
		programs whose distribution conditions are incompatible with these,
		write to the author to ask for permission.  For software which is
		copyrighted by the Free Software Foundation, write to the Free
		Software Foundation; we sometimes make exceptions for this.  Our
		decision will be guided by the two goals of preserving the free status
		of all derivatives of our free software and of promoting the sharing
		and reuse of software generally.

					    NO WARRANTY

		  15. BECAUSE THE LIBRARY IS LICENSED FREE OF CHARGE, THERE IS NO
		WARRANTY FOR THE LIBRARY, TO THE EXTENT PERMITTED BY APPLICABLE LAW.
		EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR
		OTHER PARTIES PROVIDE THE LIBRARY "AS IS" WITHOUT WARRANTY OF ANY
		KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
		IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
		PURPOSE.  THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
		LIBRARY IS WITH YOU.  SHOULD THE LIBRARY PROVE DEFECTIVE, YOU ASSUME
		THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.

		  16. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN
		WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY
		AND/OR REDISTRIBUTE THE LIBRARY AS PERMITTED ABOVE, BE LIABLE TO YOU
		FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR
		CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
		LIBRARY (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
		RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
		FAILURE OF THE LIBRARY TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
		SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
		DAMAGES.

				     END OF TERMS AND CONDITIONS

		           How to Apply These Terms to Your New Libraries

		  If you develop a new library, and you want it to be of the greatest
		possible use to the public, we recommend making it free software that
		everyone can redistribute and change.  You can do so by permitting
		redistribution under these terms (or, alternatively, under the terms of the
		ordinary General Public License).

		  To apply these terms, attach the following notices to the library.  It is
		safest to attach them to the start of each source file to most effectively
		convey the exclusion of warranty; and each file should have at least the
		"copyright" line and a pointer to where the full notice is found.

		    <one line to give the library's name and a brief idea of what it does.>
		    Copyright (C) <year>  <name of author>

		    This library is free software; you can redistribute it and/or
		    modify it under the terms of the GNU Lesser General Public
		    License as published by the Free Software Foundation; either
		    version 2.1 of the License, or (at your option) any later version.

		    This library is distributed in the hope that it will be useful,
		    but WITHOUT ANY WARRANTY; without even the implied warranty of
		    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
		    Lesser General Public License for more details.

		    You should have received a copy of the GNU Lesser General Public
		    License along with this library; if not, write to the Free Software
		    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

		Also add information on how to contact you by electronic and paper mail.

		You should also get your employer (if you work as a programmer) or your
		school, if any, to sign a "copyright disclaimer" for the library, if
		necessary.  Here is a sample; alter the names:

		  Yoyodyne, Inc., hereby disclaims all copyright interest in the
		  library `Frob' (a library for tweaking knobs) written by James Random Hacker.

		  <signature of Ty Coon>, 1 April 1990
		  Ty Coon, President of Vice

		That's all there is to it!





* Authors
    * [dan.blanchard@gmail.com](author)



* Other Licenses



* Project URL
    https://github.com/chardet/chardet


---
---

#### **click (7.0)**


* Licenses
    * BSD-3-Clause
        * Attribution:
        Copyright © 2014 by the Pallets team.

		Some rights reserved.

		Redistribution and use in source and binary forms of the software as
		well as documentation, with or without modification, are permitted
		provided that the following conditions are met:

		\-   Redistributions of source code must retain the above copyright
		    notice, this list of conditions and the following disclaimer.

		\-   Redistributions in binary form must reproduce the above copyright
		    notice, this list of conditions and the following disclaimer in the
		    documentation and/or other materials provided with the distribution.

		\-   Neither the name of the copyright holder nor the names of its
		    contributors may be used to endorse or promote products derived from
		    this software without specific prior written permission.

		THIS SOFTWARE AND DOCUMENTATION IS PROVIDED BY THE COPYRIGHT HOLDERS AND
		CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
		BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
		FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
		COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
		INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
		NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
		USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
		ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
		(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
		THIS SOFTWARE AND DOCUMENTATION, EVEN IF ADVISED OF THE POSSIBILITY OF
		SUCH DAMAGE.

		----

		Click uses parts of optparse written by Gregory P. Ward and maintained
		by the Python Software Foundation. This is limited to code in parser.py.

		Copyright © 2001-2006 Gregory P. Ward. All rights reserved.
		Copyright © 2002-2006 Python Software Foundation. All rights reserved.



* Authors
    * [armin.ronacher@active-4.com](author)



* Other Licenses



* Project URL
    https://palletsprojects.com/p/click/


---
---

#### **click-completion (0.5.0)**


* Licenses
    * MIT
        * Attribution:
        The MIT License (MIT)

		Copyright (c) 2016 Gaëtan Lehmann

		Permission is hereby granted, free of charge, to any person obtaining a copy
		of this software and associated documentation files (the "Software"), to deal
		in the Software without restriction, including without limitation the rights
		to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
		copies of the Software, and to permit persons to whom the Software is
		furnished to do so, subject to the following conditions:

		The above copyright notice and this permission notice shall be included in all
		copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
		SOFTWARE.



* Authors
    * [gaetan.lehmann@gmail.com](author)



* Other Licenses



* Project URL
    https://github.com/glehmann/click-completion


---
---

#### **click-log (0.3.2)**


* Licenses
    * MIT
        * Attribution:
        Copyright (c) 2014-2015 Markus Unterwaditzer & contributors

		Permission is hereby granted, free of charge, to any person obtaining a copy of
		this software and associated documentation files (the "Software"), to deal in
		the Software without restriction, including without limitation the rights to
		use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
		of the Software, and to permit persons to whom the Software is furnished to do
		so, subject to the following conditions:

		The above copyright notice and this permission notice shall be included in all
		copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
		SOFTWARE.



* Authors
    * [markus@unterwaditzer.net](author)



* Other Licenses



* Project URL
    https://github.com/click-contrib/click-log


---
---

#### **colorama (0.3.9)**


* Licenses
    * BSD-2-Clause
        * Attribution:
        Copyright (c) 2010 Jonathan Hartley
		All rights reserved.

		Redistribution and use in source and binary forms, with or without
		modification, are permitted provided that the following conditions are met:

		\* Redistributions of source code must retain the above copyright notice, this
		  list of conditions and the following disclaimer.

		\* Redistributions in binary form must reproduce the above copyright notice,
		  this list of conditions and the following disclaimer in the documentation
		  and/or other materials provided with the distribution.

		\* Neither the name of the copyright holders, nor those of its contributors
		  may be used to endorse or promote products derived from this software without
		  specific prior written permission.

		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
		ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
		WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
		DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
		FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
		DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
		SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
		CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
		OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
		OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.




* Authors
    * [tartley@tartley.com](author)



* Other Licenses
    * BSD-3-Clause



* Project URL
    https://github.com/tartley/colorama


---
---

#### **cookiecutter (1.6.0)**


* Licenses
    * BSD-3-Clause
        * Attribution:
        Copyright (c) 2013-2017, Audrey Roy
		All rights reserved.

		Redistribution and use in source and binary forms, with or
		without modification, are permitted provided that the following
		conditions are met:

		\* Redistributions of source code must retain the above copyright
		notice, this list of conditions and the following disclaimer.

		\* Redistributions in binary form must reproduce the above
		copyright notice, this list of conditions and the following
		disclaimer in the documentation and/or other materials provided
		with the distribution.

		\* Neither the name of border nor the names of its contributors
		may be used to endorse or promote products derived from this
		software without specific prior written permission.

		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
		CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
		INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
		MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
		DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
		CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
		SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
		LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
		USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
		AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
		LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
		ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
		POSSIBILITY OF SUCH DAMAGE.



* Authors
    * [audreyr@gmail.com](author)



* Other Licenses



* Project URL
    https://github.com/audreyr/cookiecutter


---
---

#### **cryptography (2.6.1)**


* Licenses


* Authors
    * [cryptography-dev@python.org](author)



* Other Licenses
    * **Multi-license:** Python-2.0 *OR* Apache-2.0 *OR* BSD-3-Clause
    * **Multi-license:** Apache-2.0 *OR* BSD-3-Clause



* Project URL
    https://github.com/pyca/cryptography


---
---

#### **cursor (1.2.0)**


* Licenses
    * CC-BY-SA-2.5
        * Attribution:
        <<beginOptional>> CREATIVE COMMONS CORPORATION IS NOT A LAW FIRM AND DOES NOT PROVIDE LEGAL SERVICES. DISTRIBUTION OF THIS LICENSE DOES NOT CREATE AN ATTORNEY-CLIENT RELATIONSHIP. CREATIVE COMMONS PROVIDES THIS INFORMATION ON AN "AS-IS" BASIS. CREATIVE COMMONS MAKES NO WARRANTIES REGARDING THE INFORMATION PROVIDED, AND DISCLAIMS LIABILITY FOR DAMAGES RESULTING FROM ITS USE.
		License<<endOptional>>
		THE WORK (AS DEFINED BELOW) IS PROVIDED UNDER THE TERMS OF THIS CREATIVE COMMONS PUBLIC LICENSE ("CCPL" OR "LICENSE"). THE WORK IS PROTECTED BY COPYRIGHT AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.
		BY EXERCISING ANY RIGHTS TO THE WORK PROVIDED HERE, YOU ACCEPT AND AGREE TO BE BOUND BY THE TERMS OF THIS LICENSE. THE LICENSOR GRANTS YOU THE RIGHTS CONTAINED HERE IN CONSIDERATION OF YOUR ACCEPTANCE OF SUCH TERMS AND CONDITIONS.
		   1. Definitions
		      a. "Collective Work" means a work, such as a periodical issue, anthology or encyclopedia, in which the Work in its entirety in unmodified form, along with a number of other contributions, constituting separate and independent works in themselves, are assembled into a collective whole. A work that constitutes a Collective Work will not be considered a Derivative Work (as defined below) for the purposes of this License.
		      b. "Derivative Work" means a work based upon the Work or upon the Work and other pre-existing works, such as a translation, musical arrangement, dramatization, fictionalization, motion picture version, sound recording, art reproduction, abridgment, condensation, or any other form in which the Work may be recast, transformed, or adapted, except that a work that constitutes a Collective Work will not be considered a Derivative Work for the purpose of this License. For the avoidance of doubt, where the Work is a musical composition or sound recording, the synchronization of the Work in timed-relation with a moving image ("synching") will be considered a Derivative Work for the purpose of this License.
		      c. "Licensor" means the individual or entity that offers the Work under the terms of this License.
		      d. "Original Author" means the individual or entity who created the Work.
		      e. "Work" means the copyrightable work of authorship offered under the terms of this License.
		      f. "You" means an individual or entity exercising rights under this License who has not previously violated the terms of this License with respect to the Work, or who has received express permission from the Licensor to exercise rights under this License despite a previous violation.
		      g. "License Elements" means the following high-level license attributes as selected by Licensor and indicated in the title of this License: Attribution, ShareAlike.
		   2. Fair Use Rights. Nothing in this license is intended to reduce, limit, or restrict any rights arising from fair use, first sale or other limitations on the exclusive rights of the copyright owner under copyright law or other applicable laws.
		   3. License Grant. Subject to the terms and conditions of this License, Licensor hereby grants You a worldwide, royalty-free, non-exclusive, perpetual (for the duration of the applicable copyright) license to exercise the rights in the Work as stated below:
		      a. to reproduce the Work, to incorporate the Work into one or more Collective Works, and to reproduce the Work as incorporated in the Collective Works;
		      b. to create and reproduce Derivative Works;
		      c. to distribute copies or phonorecords of, display publicly, perform publicly, and perform publicly by means of a digital audio transmission the Work including as incorporated in Collective Works;
		      d. to distribute copies or phonorecords of, display publicly, perform publicly, and perform publicly by means of a digital audio transmission Derivative Works.
		      e. For the avoidance of doubt, where the work is a musical composition:
		         i. Performance Royalties Under Blanket Licenses. Licensor waives the exclusive right to collect, whether individually or via a performance rights society (e.g. ASCAP, BMI, SESAC), royalties for the public performance or public digital performance (e.g. webcast) of the Work.
		         ii. Mechanical Rights and Statutory Royalties. Licensor waives the exclusive right to collect, whether individually or via a music rights society or designated agent (e.g. Harry Fox Agency), royalties for any phonorecord You create from the Work ("cover version") and distribute, subject to the compulsory license created by 17 USC Section 115 of the US Copyright Act (or the equivalent in other jurisdictions).
		      f. Webcasting Rights and Statutory Royalties. For the avoidance of doubt, where the Work is a sound recording, Licensor waives the exclusive right to collect, whether individually or via a performance-rights society (e.g. SoundExchange), royalties for the public digital performance (e.g. webcast) of the Work, subject to the compulsory license created by 17 USC Section 114 of the US Copyright Act (or the equivalent in other jurisdictions).
		   The above rights may be exercised in all media and formats whether now known or hereafter devised. The above rights include the right to make such modifications as are technically necessary to exercise the rights in other media and formats. All rights not expressly granted by Licensor are hereby reserved.
		   4. Restrictions. The license granted in Section 3 above is expressly made subject to and limited by the following restrictions:
		      a. You may distribute, publicly display, publicly perform, or publicly digitally perform the Work only under the terms of this License, and You must include a copy of, or the Uniform Resource Identifier for, this License with every copy or phonorecord of the Work You distribute, publicly display, publicly perform, or publicly digitally perform. You may not offer or impose any terms on the Work that alter or restrict the terms of this License or the recipients' exercise of the rights granted hereunder. You may not sublicense the Work. You must keep intact all notices that refer to this License and to the disclaimer of warranties. You may not distribute, publicly display, publicly perform, or publicly digitally perform the Work with any technological measures that control access or use of the Work in a manner inconsistent with the terms of this License Agreement. The above applies to the Work as incorporated in a Collective Work, but this does not require the Collective Work apart from the Work itself to be made subject to the terms of this License. If You create a Collective Work, upon notice from any Licensor You must, to the extent practicable, remove from the Collective Work any credit as required by clause 4(c), as requested. If You create a Derivative Work, upon notice from any Licensor You must, to the extent practicable, remove from the Derivative Work any credit as required by clause 4(c), as requested.
		      b. You may distribute, publicly display, publicly perform, or publicly digitally perform a Derivative Work only under the terms of this License, a later version of this License with the same License Elements as this License, or a Creative Commons iCommons license that contains the same License Elements as this License (e.g. Attribution-ShareAlike 2.5 Japan). You must include a copy of, or the Uniform Resource Identifier for, this License or other license specified in the previous sentence with every copy or phonorecord of each Derivative Work You distribute, publicly display, publicly perform, or publicly digitally perform. You may not offer or impose any terms on the Derivative Works that alter or restrict the terms of this License or the recipients' exercise of the rights granted hereunder, and You must keep intact all notices that refer to this License and to the disclaimer of warranties. You may not distribute, publicly display, publicly perform, or publicly digitally perform the Derivative Work with any technological measures that control access or use of the Work in a manner inconsistent with the terms of this License Agreement. The above applies to the Derivative Work as incorporated in a Collective Work, but this does not require the Collective Work apart from the Derivative Work itself to be made subject to the terms of this License.
		      c. If you distribute, publicly display, publicly perform, or publicly digitally perform the Work or any Derivative Works or Collective Works, You must keep intact all copyright notices for the Work and provide, reasonable to the medium or means You are utilizing: (i) the name of the Original Author (or pseudonym, if applicable) if supplied, and/or (ii) if the Original Author and/or Licensor designate another party or parties (e.g. a sponsor institute, publishing entity, journal) for attribution in Licensor's copyright notice, terms of service or by other reasonable means, the name of such party or parties; the title of the Work if supplied; to the extent reasonably practicable, the Uniform Resource Identifier, if any, that Licensor specifies to be associated with the Work, unless such URI does not refer to the copyright notice or licensing information for the Work; and in the case of a Derivative Work, a credit identifying the use of the Work in the Derivative Work (e.g., "French translation of the Work by Original Author," or "Screenplay based on original Work by Original Author"). Such credit may be implemented in any reasonable manner; provided, however, that in the case of a Derivative Work or Collective Work, at a minimum such credit will appear where any other comparable authorship credit appears and in a manner at least as prominent as such other comparable authorship credit.
		   5. Representations, Warranties and Disclaimer
		   UNLESS OTHERWISE AGREED TO BY THE PARTIES IN WRITING, LICENSOR OFFERS THE WORK AS-IS AND MAKES NO REPRESENTATIONS OR WARRANTIES OF ANY KIND CONCERNING THE MATERIALS, EXPRESS, IMPLIED, STATUTORY OR OTHERWISE, INCLUDING, WITHOUT LIMITATION, WARRANTIES OF TITLE, MERCHANTIBILITY, FITNESS FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS, ACCURACY, OR THE PRESENCE OF ABSENCE OF ERRORS, WHETHER OR NOT DISCOVERABLE. SOME JURISDICTIONS DO NOT ALLOW THE EXCLUSION OF IMPLIED WARRANTIES, SO SUCH EXCLUSION MAY NOT APPLY TO YOU.
		   6. Limitation on Liability. EXCEPT TO THE EXTENT REQUIRED BY APPLICABLE LAW, IN NO EVENT WILL LICENSOR BE LIABLE TO YOU ON ANY LEGAL THEORY FOR ANY SPECIAL, INCIDENTAL, CONSEQUENTIAL, PUNITIVE OR EXEMPLARY DAMAGES ARISING OUT OF THIS LICENSE OR THE USE OF THE WORK, EVEN IF LICENSOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
		   7. Termination
		      a. This License and the rights granted hereunder will terminate automatically upon any breach by You of the terms of this License. Individuals or entities who have received Derivative Works or Collective Works from You under this License, however, will not have their licenses terminated provided such individuals or entities remain in full compliance with those licenses. Sections 1, 2, 5, 6, 7, and 8 will survive any termination of this License.
		      b. Subject to the above terms and conditions, the license granted here is perpetual (for the duration of the applicable copyright in the Work). Notwithstanding the above, Licensor reserves the right to release the Work under different license terms or to stop distributing the Work at any time; provided, however that any such election will not serve to withdraw this License (or any other license that has been, or is required to be, granted under the terms of this License), and this License will continue in full force and effect unless terminated as stated above.
		   8. Miscellaneous
		      a. Each time You distribute or publicly digitally perform the Work or a Collective Work, the Licensor offers to the recipient a license to the Work on the same terms and conditions as the license granted to You under this License.
		      b. Each time You distribute or publicly digitally perform a Derivative Work, Licensor offers to the recipient a license to the original Work on the same terms and conditions as the license granted to You under this License.
		      c. If any provision of this License is invalid or unenforceable under applicable law, it shall not affect the validity or enforceability of the remainder of the terms of this License, and without further action by the parties to this agreement, such provision shall be reformed to the minimum extent necessary to make such provision valid and enforceable.
		      d. No term or provision of this License shall be deemed waived and no breach consented to unless such waiver or consent shall be in writing and signed by the party to be charged with such waiver or consent.
		      e. This License constitutes the entire agreement between the parties with respect to the Work licensed here. There are no understandings, agreements or representations with respect to the Work not specified here. Licensor shall not be bound by any additional provisions that may appear in any communication from You. This License may not be modified without the mutual written agreement of the Licensor and You.
		Creative Commons is not a party to this License, and makes no warranty whatsoever in connection with the Work. Creative Commons will not be liable to You or any party on any legal theory for any damages whatsoever, including without limitation any general, special, incidental or consequential damages arising in connection to this license. Notwithstanding the foregoing two (2) sentences, if Creative Commons has expressly identified itself as the Licensor hereunder, it shall have all rights and obligations of Licensor.
		Except for the limited purpose of indicating to the public that the Work is licensed under the CCPL, neither party will use the trademark "Creative Commons" or any related trademark or logo of Creative Commons without the prior written consent of Creative Commons. Any permitted use will be in compliance with Creative Commons' then-current trademark usage guidelines, as may be published on its website or otherwise made available upon request from time to time.
		Creative Commons may be contacted at http://creativecommons.org/.


* Authors
    * [gijs.timmers@student.kuleuven.be](author)



* Other Licenses



* Project URL
    https://github.com/GijsTimmers/cursor


---
---

#### **decorator (4.4.0)**


* Licenses
    * BSD-3-Clause
        * Attribution:
        Copyright (c) 2005-2018, Michele Simionato
		All rights reserved.

		Redistribution and use in source and binary forms, with or without
		modification, are permitted provided that the following conditions are
		met:

		  Redistributions of source code must retain the above copyright
		  notice, this list of conditions and the following disclaimer.
		  Redistributions in bytecode form must reproduce the above copyright
		  notice, this list of conditions and the following disclaimer in
		  the documentation and/or other materials provided with the
		  distribution.

		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
		"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
		LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
		A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
		HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
		INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
		BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
		OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
		ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
		TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
		USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
		DAMAGE.



* Authors
    * [michele.simionato@gmail.com](author)



* Other Licenses



* Project URL
    https://github.com/micheles/decorator


---
---

#### **dogpile.cache (0.7.1)**


* Licenses
    * BSD-2-Clause
        * Attribution:
        Copyright (c) 2011-2018 Mike Bayer

		All rights reserved.

		Redistribution and use in source and binary forms, with or without
		modification, are permitted provided that the following conditions
		are met:
		1\. Redistributions of source code must retain the above copyright
		   notice, this list of conditions and the following disclaimer.
		2\. Redistributions in binary form must reproduce the above copyright
		   notice, this list of conditions and the following disclaimer in the
		   documentation and/or other materials provided with the distribution.
		3\. The name of the author or contributors may not be used to endorse or
		   promote products derived from this software without specific prior
		   written permission.

		THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
		ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
		IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
		ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
		FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
		DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
		OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
		HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
		LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
		OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
		SUCH DAMAGE.



* Authors
    * [mike_mp@zzzcomputing.com](author)



* Other Licenses
    * BSD-3-Clause



* Project URL
    http://bitbucket.org/zzzeek/dogpile.cache


---
---

#### **exodus-bundler (2.0.2)**


* Licenses
    * BSD-3-Clause
        * Attribution:
        Copyright (c) 2019, exodus-bundler Contributors . All rights reserved.
		Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
		   1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
		   2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
		   3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    * BSD-2-Clause
        * Attribution:
        2-Clause BSD License
		======================

		*Copyright © `2017-present`, `Intoli, LLC`*

		*https://github.com/intoli/exodus/*

		*https://intoli.com/*

		*All rights reserved.*

		Redistribution and use in source and binary forms, with or without
		modification, are permitted provided that the following conditions are met:

		1\. Redistributions of source code must retain the above copyright notice, this
		   list of conditions and the following disclaimer.
		2\. Redistributions in binary form must reproduce the above copyright notice,
		   this list of conditions and the following disclaimer in the documentation
		   and/or other materials provided with the distribution.

		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS “AS IS” AND
		ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
		WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
		DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
		ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
		(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
		LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
		ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
		(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
		SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

		The views and conclusions contained in the software and documentation are those
		of the authors and should not be interpreted as representing official policies,
		either expressed or implied, of the FreeBSD Project.



* Authors
    * [contact@intoli.com](author)



* Other Licenses



* Project URL
    https://github.com/intoli/exodus


---
---

#### **future (0.17.1)**


* Licenses
    * MIT
        * Attribution:
        Copyright (c) 2013-2018 Python Charmers Pty Ltd, Australia

		Permission is hereby granted, free of charge, to any person obtaining a copy
		of this software and associated documentation files (the "Software"), to deal
		in the Software without restriction, including without limitation the rights
		to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
		copies of the Software, and to permit persons to whom the Software is
		furnished to do so, subject to the following conditions:

		The above copyright notice and this permission notice shall be included in
		all copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
		THE SOFTWARE.



* Authors
    * [ed@pythoncharmers.com](author)



* Other Licenses
    * Python-2.0
    * BSD-3-Clause
    * GPL-2.0-only



* Project URL
    https://python-future.org


---
---

#### **halo (0.0.26)**


* Licenses
    * MIT
        * Attribution:
        MIT License

		Copyright (c) 2017 Manraj Singh

		Permission is hereby granted, free of charge, to any person obtaining a copy
		of this software and associated documentation files (the "Software"), to deal
		in the Software without restriction, including without limitation the rights
		to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
		copies of the Software, and to permit persons to whom the Software is
		furnished to do so, subject to the following conditions:

		The above copyright notice and this permission notice shall be included in all
		copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
		SOFTWARE.



* Authors
    * [manrajsinghgrover@gmail.com](author)



* Other Licenses



* Project URL
    https://github.com/manrajgrover/halo


---
---

#### **idna (2.8)**


* Licenses
    * BSD-3-Clause
        * Attribution:
        License
		-------

		Copyright (c) 2013-2018, Kim Davies. All rights reserved.

		Redistribution and use in source and binary forms, with or without
		modification, are permitted provided that the following conditions are met:

		#. Redistributions of source code must retain the above copyright
		   notice, this list of conditions and the following disclaimer.

		#. Redistributions in binary form must reproduce the above
		   copyright notice, this list of conditions and the following
		   disclaimer in the documentation and/or other materials provided with
		   the distribution.

		#. Neither the name of the copyright holder nor the names of the
		   contributors may be used to endorse or promote products derived
		   from this software without specific prior written permission.

		#. THIS SOFTWARE IS PROVIDED BY THE CONTRIBUTORS "AS IS" AND ANY
		   EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
		   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
		   PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR
		   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
		   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
		   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
		   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
		   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
		   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
		   USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
		   DAMAGE.

		Portions of the codec implementation and unit tests are derived from the
		Python standard library, which carries the `Python Software Foundation
		License <https://docs.python.org/2/license.html>`_:

		   Copyright (c) 2001-2014 Python Software Foundation; All Rights Reserved

		Portions of the unit tests are derived from the Unicode standard, which
		is subject to the Unicode, Inc. License Agreement:

		   Copyright (c) 1991-2014 Unicode, Inc. All rights reserved.
		   Distributed under the Terms of Use in
		   <http://www.unicode.org/copyright.html>.

		   Permission is hereby granted, free of charge, to any person obtaining
		   a copy of the Unicode data files and any associated documentation
		   (the "Data Files") or Unicode software and any associated documentation
		   (the "Software") to deal in the Data Files or Software
		   without restriction, including without limitation the rights to use,
		   copy, modify, merge, publish, distribute, and/or sell copies of
		   the Data Files or Software, and to permit persons to whom the Data Files
		   or Software are furnished to do so, provided that

		   (a) this copyright and permission notice appear with all copies
		   of the Data Files or Software,

		   (b) this copyright and permission notice appear in associated
		   documentation, and

		   (c) there is clear notice in each modified Data File or in the Software
		   as well as in the documentation associated with the Data File(s) or
		   Software that the data or software has been modified.

		   THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
		   ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
		   WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
		   NONINFRINGEMENT OF THIRD PARTY RIGHTS.
		   IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
		   NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
		   DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
		   DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
		   TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
		   PERFORMANCE OF THE DATA FILES OR SOFTWARE.

		   Except as contained in this notice, the name of a copyright holder
		   shall not be used in advertising or otherwise to promote the sale,
		   use or other dealings in these Data Files or Software without prior
		   written authorization of the copyright holder.

    * **Multi-license:** BSD-3-Clause
        * Attribution:
        License
		-------

		Copyright (c) 2013-2018, Kim Davies. All rights reserved.

		Redistribution and use in source and binary forms, with or without
		modification, are permitted provided that the following conditions are met:

		#. Redistributions of source code must retain the above copyright
		   notice, this list of conditions and the following disclaimer.

		#. Redistributions in binary form must reproduce the above
		   copyright notice, this list of conditions and the following
		   disclaimer in the documentation and/or other materials provided with
		   the distribution.

		#. Neither the name of the copyright holder nor the names of the
		   contributors may be used to endorse or promote products derived
		   from this software without specific prior written permission.

		#. THIS SOFTWARE IS PROVIDED BY THE CONTRIBUTORS "AS IS" AND ANY
		   EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
		   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
		   PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR
		   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
		   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
		   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
		   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
		   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
		   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
		   USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
		   DAMAGE.

		Portions of the codec implementation and unit tests are derived from the
		Python standard library, which carries the `Python Software Foundation
		License <https://docs.python.org/2/license.html>`_:

		   Copyright (c) 2001-2014 Python Software Foundation; All Rights Reserved

		Portions of the unit tests are derived from the Unicode standard, which
		is subject to the Unicode, Inc. License Agreement:

		   Copyright (c) 1991-2014 Unicode, Inc. All rights reserved.
		   Distributed under the Terms of Use in
		   <http://www.unicode.org/copyright.html>.

		   Permission is hereby granted, free of charge, to any person obtaining
		   a copy of the Unicode data files and any associated documentation
		   (the "Data Files") or Unicode software and any associated documentation
		   (the "Software") to deal in the Data Files or Software
		   without restriction, including without limitation the rights to use,
		   copy, modify, merge, publish, distribute, and/or sell copies of
		   the Data Files or Software, and to permit persons to whom the Data Files
		   or Software are furnished to do so, provided that

		   (a) this copyright and permission notice appear with all copies
		   of the Data Files or Software,

		   (b) this copyright and permission notice appear in associated
		   documentation, and

		   (c) there is clear notice in each modified Data File or in the Software
		   as well as in the documentation associated with the Data File(s) or
		   Software that the data or software has been modified.

		   THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
		   ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
		   WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
		   NONINFRINGEMENT OF THIRD PARTY RIGHTS.
		   IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
		   NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
		   DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
		   DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
		   TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
		   PERFORMANCE OF THE DATA FILES OR SOFTWARE.

		   Except as contained in this notice, the name of a copyright holder
		   shall not be used in advertising or otherwise to promote the sale,
		   use or other dealings in these Data Files or Software without prior
		   written authorization of the copyright holder.
		 *OR* Python-2.0
        * Attribution:
        1\. This LICENSE AGREEMENT is between the Python Software Foundation ("PSF"), and the Individual or Organization ("Licensee") accessing and otherwise using this software ("Python") in source or binary form and its associated documentation.
		   2. Subject to the terms and conditions of this License Agreement, PSF hereby grants Licensee a nonexclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python alone or in any derivative version, provided, however, that PSF's License Agreement and PSF's notice of copyright, i.e., "Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved" are retained in Python alone or in any derivative version prepared by Licensee.
		   3. In the event Licensee prepares a derivative work that is based on or incorporates Python or any part thereof, and wants to make the derivative work available to others as provided herein, then Licensee hereby agrees to include in any such work a brief summary of the changes made to Python.
		   4. PSF is making Python available to Licensee on an "AS IS" basis. PSF MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, PSF MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
		   5. PSF SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF PYTHON FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF MODIFYING, DISTRIBUTING, OR OTHERWISE USING PYTHON, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
		   6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
		   7. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between PSF and Licensee. This License Agreement does not grant permission to use PSF trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
		   8. By copying, installing or otherwise using Python, Licensee agrees to be bound by the terms and conditions of this License Agreement.<<beginOptional>> BEOPEN.COM LICENSE AGREEMENT FOR PYTHON 2.0
		BEOPEN PYTHON OPEN SOURCE LICENSE AGREEMENT VERSION 1<<endOptional>>
		   1. This LICENSE AGREEMENT is between BeOpen.com ("BeOpen"), having an office at 160 Saratoga Avenue, Santa Clara, CA 95051, and the Individual or Organization ("Licensee") accessing and otherwise using this software in source or binary form and its associated documentation ("the Software").
		   2. Subject to the terms and conditions of this BeOpen Python License Agreement, BeOpen hereby grants Licensee a non-exclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use the Software alone or in any derivative version, provided, however, that the BeOpen Python License is retained in the Software, alone or in any derivative version prepared by Licensee.
		   3. BeOpen is making the Software available to Licensee on an "AS IS" basis. BEOPEN MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, BEOPEN MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF THE SOFTWARE WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
		   4. BEOPEN SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF THE SOFTWARE FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THE SOFTWARE, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
		   5. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
		   6. This License Agreement shall be governed by and interpreted in all respects by the law of the State of California, excluding conflict of law provisions. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between BeOpen and Licensee. This License Agreement does not grant permission to use BeOpen trademarks or trade names in a trademark sense to endorse or promote products or services of Licensee, or any third party. As an exception, the "BeOpen Python" logos available at http://www.pythonlabs.com/logos.html may be used according to the permissions granted on that web page.
		   7. By copying, installing or otherwise using the software, Licensee agrees to be bound by the terms and conditions of this License Agreement.<<beginOptional>> IMPORTANT: PLEASE READ THE FOLLOWING AGREEMENT CAREFULLY.
		BY CLICKING ON "ACCEPT" WHERE INDICATED BELOW, OR BY COPYING, INSTALLING OR OTHERWISE USING PYTHON 1.6, beta 1 SOFTWARE, YOU ARE DEEMED TO HAVE AGREED TO THE TERMS AND CONDITIONS OF THIS LICENSE AGREEMENT.<<endOptional>>
		   1. This LICENSE AGREEMENT is between the Corporation for National Research Initiatives, having an office at 1895 Preston White Drive, Reston, VA 20191 ("CNRI"), and the Individual or Organization ("Licensee") accessing and otherwise using Python 1.6, beta 1 software in source or binary form and its associated documentation, as released at the www.python.org Internet site on August 4, 2000 ("Python 1.6b1").
		   2. Subject to the terms and conditions of this License Agreement, CNRI hereby grants Licensee a non-exclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python 1.6b1 alone or in any derivative version, provided, however, that CNRIs License Agreement is retained in Python 1.6b1, alone or in any derivative version prepared by Licensee.
		   Alternately, in lieu of CNRIs License Agreement, Licensee may substitute the following text (omitting the quotes): "Python 1.6, beta 1, is made available subject to the terms and conditions in CNRIs License Agreement. This Agreement may be located on the Internet using the following unique, persistent identifier (known as a handle): 1895.22/1011. This Agreement may also be obtained from a proxy server on the Internet using the URL:http://hdl.handle.net/1895.22/1011".
		   3. In the event Licensee prepares a derivative work that is based on or incorporates Python 1.6b1 or any part thereof, and wants to make the derivative work available to the public as provided herein, then Licensee hereby agrees to indicate in any such work the nature of the modifications made to Python 1.6b1.
		   4. CNRI is making Python 1.6b1 available to Licensee on an "AS IS" basis. CNRI MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, CNRI MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON 1.6b1 WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
		   5. CNRI SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF THE SOFTWARE FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF USING, MODIFYING OR DISTRIBUTING PYTHON 1.6b1, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
		   6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
		   7. This License Agreement shall be governed by and interpreted in all respects by the law of the State of Virginia, excluding conflict of law provisions. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between CNRI and Licensee. This License Agreement does not grant permission to use CNRI trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
		   8. By clicking on the "ACCEPT" button where indicated, or by copying, installing or otherwise using Python 1.6b1, Licensee agrees to be bound by the terms and conditions of this License Agreement.
		Copyright (c) 1991 - 1995, Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.
		Permission to use, copy, modify, and distribute this software and its documentation for any purpose and without fee is hereby granted, provided that the above copyright notice appear in all copies and that both that copyright notice and this permission notice appear in supporting documentation, and that the name of Stichting Mathematisch Centrum or CWI not be used in advertising or publicity pertaining to distribution of the software without specific, written prior permission.
		STICHTING MATHEMATISCH CENTRUM DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL STICHTING MATHEMATISCH CENTRUM BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.


* Authors
    * [kim@cynosure.com.au](author)



* Other Licenses



* Project URL
    https://github.com/kjd/idna


---
---

#### **Jinja2 (2.10.1)**


* Licenses
    * BSD-3-Clause
        * Attribution:
        Copyright (c) 2009 by the Jinja Team, see AUTHORS for more details.

		Some rights reserved.

		Redistribution and use in source and binary forms, with or without
		modification, are permitted provided that the following conditions are
		met:

		    * Redistributions of source code must retain the above copyright
		      notice, this list of conditions and the following disclaimer.

		    * Redistributions in binary form must reproduce the above
		      copyright notice, this list of conditions and the following
		      disclaimer in the documentation and/or other materials provided
		      with the distribution.

		    * The names of the contributors may not be used to endorse or
		      promote products derived from this software without specific
		      prior written permission.

		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
		"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
		LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
		A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
		OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
		SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
		LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
		DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
		THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
		(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
		OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.



* Authors
    * [armin.ronacher@active-4.com](author)



* Other Licenses
    * GPL-2.0-or-later



* Project URL
    http://jinja.pocoo.org/


---
---

#### **jinja2-time (0.2.0)**


* Licenses
    * MIT
        * Attribution:
        The MIT License (MIT)

		Copyright (c) 2015 Raphael Pierzina

		Permission is hereby granted, free of charge, to any person obtaining a copy
		of this software and associated documentation files (the "Software"), to deal
		in the Software without restriction, including without limitation the rights
		to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
		copies of the Software, and to permit persons to whom the Software is
		furnished to do so, subject to the following conditions:

		The above copyright notice and this permission notice shall be included in all
		copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
		SOFTWARE.




* Authors
    * [raphael@hackebrot.de](author)



* Other Licenses



* Project URL
    https://github.com/hackebrot/jinja2-time


---
---

#### **log-symbols (0.0.13)**


* Licenses
    * MIT
        * Attribution:
        MIT License

		Copyright (c) 2017 Manraj Singh

		Permission is hereby granted, free of charge, to any person obtaining a copy
		of this software and associated documentation files (the "Software"), to deal
		in the Software without restriction, including without limitation the rights
		to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
		copies of the Software, and to permit persons to whom the Software is
		furnished to do so, subject to the following conditions:

		The above copyright notice and this permission notice shall be included in all
		copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
		SOFTWARE.



* Authors
    * [manrajsinghgrover@gmail.com](author)



* Other Licenses



* Project URL
    https://github.com/manrajgrover/py-log-symbols


---
---

#### **Markdown (3.1.1)**


* Licenses
    * BSD-3-Clause
        * Attribution:
        Copyright 2007, 2008 The Python Markdown Project (v. 1.7 and later)
		Copyright 2004, 2005, 2006 Yuri Takhteyev (v. 0.2-1.6b)
		Copyright 2004 Manfred Stienstra (the original version)

		All rights reserved.

		Redistribution and use in source and binary forms, with or without
		modification, are permitted provided that the following conditions are met:

		\* Redistributions of source code must retain the above copyright
		  notice, this list of conditions and the following disclaimer.
		\* Redistributions in binary form must reproduce the above copyright
		  notice, this list of conditions and the following disclaimer in the
		  documentation and/or other materials provided with the distribution.
		\* Neither the name of the Python Markdown Project nor the
		  names of its contributors may be used to endorse or promote products
		  derived from this software without specific prior written permission.

		THIS SOFTWARE IS PROVIDED BY THE PYTHON MARKDOWN PROJECT ''AS IS'' AND ANY
		EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
		WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
		DISCLAIMED. IN NO EVENT SHALL ANY CONTRIBUTORS TO THE PYTHON MARKDOWN PROJECT
		BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
		CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
		SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
		INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
		CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
		ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
		POSSIBILITY OF SUCH DAMAGE.



* Authors
    * [waylan.limberg@icloud.com](author)



* Other Licenses
    * **Multi-license:** BSD-3-Clause *OR* Python-2.0
    * MIT



* Project URL
    https://pythonhosted.org/Markdown/


---
---

#### **MarkupSafe (1.1.1)**


* Licenses
    * BSD-3-Clause
        * Attribution:
        Copyright 2010 Pallets

		Redistribution and use in source and binary forms, with or without
		modification, are permitted provided that the following conditions are
		met:

		1\.  Redistributions of source code must retain the above copyright
		    notice, this list of conditions and the following disclaimer.

		2\.  Redistributions in binary form must reproduce the above copyright
		    notice, this list of conditions and the following disclaimer in the
		    documentation and/or other materials provided with the distribution.

		3\.  Neither the name of the copyright holder nor the names of its
		    contributors may be used to endorse or promote products derived from
		    this software without specific prior written permission.

		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
		"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
		LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
		PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
		HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
		SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
		TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
		PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
		LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
		NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
		SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.



* Authors
    * [armin.ronacher@active-4.com](author)



* Other Licenses



* Project URL
    http://github.com/mitsuhiko/markupsafe


---
---

#### **mdv (1.7.4)**


* Licenses
    * BSD-3-Clause
        * Attribution:
        BSD License

		For Axiros Software

		Copyright (c) 2002-2016, Axiros GmbH
		All rights reserved.

		Redistribution and use in source and binary forms, with or without modification,
		are permitted provided that the following conditions are met:

		 * Redistributions of source code must retain the above copyright notice, this
		   list of conditions and the following disclaimer.

		 * Redistributions in binary form must reproduce the above copyright notice,
		   this list of conditions and the following disclaimer in the documentation
		   and/or other materials provided with the distribution.

		 * Neither the name Axiros nor the names of its contributors may be used to
		   endorse or promote products derived from this software without specific
		   prior written permission.

		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
		ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
		WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
		DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
		ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
		(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
		LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
		ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
		(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
		SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.



* Authors
    * [gk@axiros.com](author)



* Other Licenses
    * MIT



* Project URL
    http://github.com/axiros/terminal_markdown_viewer


---
---

#### **passlib (1.7.1)**


* Licenses
    * MIT
        * Attribution:
        .. -*- restructuredtext -*-

		=====================
		Copyrights & Licenses
		=====================

		Credits
		=======
		Passlib is primarily developed by Eli Collins.

		Special thanks to Darin Gordon for testing and
		feedback on the :mod:`passlib.totp` module.

		License for Passlib
		===================
		Passlib is (c) `Assurance Technologies <http://www.assurancetechnologies.com>`_,
		and is released under the `BSD license <http://www.opensource.org/licenses/bsd-license.php>`_::

		    Passlib
		    Copyright (c) 2008-2017 Assurance Technologies, LLC.
		    All rights reserved.

		    Redistribution and use in source and binary forms, with or without
		    modification, are permitted provided that the following conditions are
		    met:

		    * Redistributions of source code must retain the above copyright
		      notice, this list of conditions and the following disclaimer.

		    * Redistributions in binary form must reproduce the above copyright
		      notice, this list of conditions and the following disclaimer in the
		      documentation and/or other materials provided with the distribution.

		    * Neither the name of Assurance Technologies, nor the names of the
		      contributors may be used to endorse or promote products derived
		      from this software without specific prior written permission.

		    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
		    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
		    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
		    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
		    OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
		    SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
		    LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
		    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
		    THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
		    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
		    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

		Licenses for incorporated software
		==================================
		Passlib contains some code derived from the following sources:

		MD5-Crypt
		---------
		The source file ``passlib/handlers/md5_crypt.py`` contains code derived from the original
		`FreeBSD md5-crypt implementation <http://www.freebsd.org/cgi/cvsweb.cgi/~checkout~/src/lib/libcrypt/crypt.c?rev=1.2>`_,
		which is available under the following license::

		    "THE BEER-WARE LICENSE" (Revision 42):
		    <phk@login.dknet.dk> wrote this file.  As long as you retain this notice you
		    can do whatever you want with this stuff. If we meet some day, and you think
		    this stuff is worth it, you can buy me a beer in return.   Poul-Henning Kamp

		    converted to python May 2008
		    by Eli Collins

		DES
		---
		The source file ``passlib/crypto/des.py`` contains code derived from
		`UnixCrypt.java <http://www.dynamic.net.au/christos/crypt/UnixCrypt2.txt>`_,
		a pure-java implementation of the historic unix-crypt password hash algorithm.
		It is available under the following license::

		    UnixCrypt.java 0.9 96/11/25
		    Copyright (c) 1996 Aki Yoshida. All rights reserved.
		    Permission to use, copy, modify and distribute this software
		    for non-commercial or commercial purposes and without fee is
		    hereby granted provided that this copyright notice appears in
		    all copies.

		    modified April 2001
		    by Iris Van den Broeke, Daniel Deville

		    modified Aug 2005
		    by Greg Wilkins (gregw)

		    converted to python Jun 2009
		    by Eli Collins

		jBCrypt
		-------
		The source file ``passlib/crypto/_blowfish/base.py`` contains code derived
		from `jBcrypt 0.2 <http://www.mindrot.org/projects/jBCrypt/>`_, a Java
		implementation of the BCrypt password hash algorithm. It is available under
		a BSD/ISC license::

		    Copyright (c) 2006 Damien Miller <djm@mindrot.org>

		    Permission to use, copy, modify, and distribute this software for any
		    purpose with or without fee is hereby granted, provided that the above
		    copyright notice and this permission notice appear in all copies.

		    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
		    WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
		    MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
		    ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
		    WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
		    ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTUOUS ACTION, ARISING OUT OF
		    OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

		Wordsets
		--------
		The EFF wordsets in ``passlib/_data/wordsets`` are (c) 2016 the Electronic Freedom Foundation.
		They were downloaded from `<https://www.eff.org/deeplinks/2016/07/new-wordlists-random-passphrases>`_,
		and are released under the `Creative Commons License <https://www.eff.org/copyright>`_.

    * BSD-3-Clause
        * Attribution:
        Copyright (c) 2019, passlib Contributors . All rights reserved.
		Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
		   1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
		   2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
		   3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


* Authors
    * [elic@assurancetechnologies.com](author)



* Other Licenses
    * Apache-2.0



* Project URL
    https://bitbucket.org/ecollins/passlib


---
---

#### **pbr (5.2.0)**


* Licenses
    * Apache-2.0
        * Attribution:

		                                 Apache License
		                           Version 2.0, January 2004
		                        http://www.apache.org/licenses/

		   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

		   1. Definitions.

		      "License" shall mean the terms and conditions for use, reproduction,
		      and distribution as defined by Sections 1 through 9 of this document.

		      "Licensor" shall mean the copyright owner or entity authorized by
		      the copyright owner that is granting the License.

		      "Legal Entity" shall mean the union of the acting entity and all
		      other entities that control, are controlled by, or are under common
		      control with that entity. For the purposes of this definition,
		      "control" means (i) the power, direct or indirect, to cause the
		      direction or management of such entity, whether by contract or
		      otherwise, or (ii) ownership of fifty percent (50%) or more of the
		      outstanding shares, or (iii) beneficial ownership of such entity.

		      "You" (or "Your") shall mean an individual or Legal Entity
		      exercising permissions granted by this License.

		      "Source" form shall mean the preferred form for making modifications,
		      including but not limited to software source code, documentation
		      source, and configuration files.

		      "Object" form shall mean any form resulting from mechanical
		      transformation or translation of a Source form, including but
		      not limited to compiled object code, generated documentation,
		      and conversions to other media types.

		      "Work" shall mean the work of authorship, whether in Source or
		      Object form, made available under the License, as indicated by a
		      copyright notice that is included in or attached to the work
		      (an example is provided in the Appendix below).

		      "Derivative Works" shall mean any work, whether in Source or Object
		      form, that is based on (or derived from) the Work and for which the
		      editorial revisions, annotations, elaborations, or other modifications
		      represent, as a whole, an original work of authorship. For the purposes
		      of this License, Derivative Works shall not include works that remain
		      separable from, or merely link (or bind by name) to the interfaces of,
		      the Work and Derivative Works thereof.

		      "Contribution" shall mean any work of authorship, including
		      the original version of the Work and any modifications or additions
		      to that Work or Derivative Works thereof, that is intentionally
		      submitted to Licensor for inclusion in the Work by the copyright owner
		      or by an individual or Legal Entity authorized to submit on behalf of
		      the copyright owner. For the purposes of this definition, "submitted"
		      means any form of electronic, verbal, or written communication sent
		      to the Licensor or its representatives, including but not limited to
		      communication on electronic mailing lists, source code control systems,
		      and issue tracking systems that are managed by, or on behalf of, the
		      Licensor for the purpose of discussing and improving the Work, but
		      excluding communication that is conspicuously marked or otherwise
		      designated in writing by the copyright owner as "Not a Contribution."

		      "Contributor" shall mean Licensor and any individual or Legal Entity
		      on behalf of whom a Contribution has been received by Licensor and
		      subsequently incorporated within the Work.

		   2. Grant of Copyright License. Subject to the terms and conditions of
		      this License, each Contributor hereby grants to You a perpetual,
		      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
		      copyright license to reproduce, prepare Derivative Works of,
		      publicly display, publicly perform, sublicense, and distribute the
		      Work and such Derivative Works in Source or Object form.

		   3. Grant of Patent License. Subject to the terms and conditions of
		      this License, each Contributor hereby grants to You a perpetual,
		      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
		      (except as stated in this section) patent license to make, have made,
		      use, offer to sell, sell, import, and otherwise transfer the Work,
		      where such license applies only to those patent claims licensable
		      by such Contributor that are necessarily infringed by their
		      Contribution(s) alone or by combination of their Contribution(s)
		      with the Work to which such Contribution(s) was submitted. If You
		      institute patent litigation against any entity (including a
		      cross-claim or counterclaim in a lawsuit) alleging that the Work
		      or a Contribution incorporated within the Work constitutes direct
		      or contributory patent infringement, then any patent licenses
		      granted to You under this License for that Work shall terminate
		      as of the date such litigation is filed.

		   4. Redistribution. You may reproduce and distribute copies of the
		      Work or Derivative Works thereof in any medium, with or without
		      modifications, and in Source or Object form, provided that You
		      meet the following conditions:

		      (a) You must give any other recipients of the Work or
		          Derivative Works a copy of this License; and

		      (b) You must cause any modified files to carry prominent notices
		          stating that You changed the files; and

		      (c) You must retain, in the Source form of any Derivative Works
		          that You distribute, all copyright, patent, trademark, and
		          attribution notices from the Source form of the Work,
		          excluding those notices that do not pertain to any part of
		          the Derivative Works; and

		      (d) If the Work includes a "NOTICE" text file as part of its
		          distribution, then any Derivative Works that You distribute must
		          include a readable copy of the attribution notices contained
		          within such NOTICE file, excluding those notices that do not
		          pertain to any part of the Derivative Works, in at least one
		          of the following places: within a NOTICE text file distributed
		          as part of the Derivative Works; within the Source form or
		          documentation, if provided along with the Derivative Works; or,
		          within a display generated by the Derivative Works, if and
		          wherever such third-party notices normally appear. The contents
		          of the NOTICE file are for informational purposes only and
		          do not modify the License. You may add Your own attribution
		          notices within Derivative Works that You distribute, alongside
		          or as an addendum to the NOTICE text from the Work, provided
		          that such additional attribution notices cannot be construed
		          as modifying the License.

		      You may add Your own copyright statement to Your modifications and
		      may provide additional or different license terms and conditions
		      for use, reproduction, or distribution of Your modifications, or
		      for any such Derivative Works as a whole, provided Your use,
		      reproduction, and distribution of the Work otherwise complies with
		      the conditions stated in this License.

		   5. Submission of Contributions. Unless You explicitly state otherwise,
		      any Contribution intentionally submitted for inclusion in the Work
		      by You to the Licensor shall be under the terms and conditions of
		      this License, without any additional terms or conditions.
		      Notwithstanding the above, nothing herein shall supersede or modify
		      the terms of any separate license agreement you may have executed
		      with Licensor regarding such Contributions.

		   6. Trademarks. This License does not grant permission to use the trade
		      names, trademarks, service marks, or product names of the Licensor,
		      except as required for reasonable and customary use in describing the
		      origin of the Work and reproducing the content of the NOTICE file.

		   7. Disclaimer of Warranty. Unless required by applicable law or
		      agreed to in writing, Licensor provides the Work (and each
		      Contributor provides its Contributions) on an "AS IS" BASIS,
		      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
		      implied, including, without limitation, any warranties or conditions
		      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
		      PARTICULAR PURPOSE. You are solely responsible for determining the
		      appropriateness of using or redistributing the Work and assume any
		      risks associated with Your exercise of permissions under this License.

		   8. Limitation of Liability. In no event and under no legal theory,
		      whether in tort (including negligence), contract, or otherwise,
		      unless required by applicable law (such as deliberate and grossly
		      negligent acts) or agreed to in writing, shall any Contributor be
		      liable to You for damages, including any direct, indirect, special,
		      incidental, or consequential damages of any character arising as a
		      result of this License or out of the use or inability to use the
		      Work (including but not limited to damages for loss of goodwill,
		      work stoppage, computer failure or malfunction, or any and all
		      other commercial damages or losses), even if such Contributor
		      has been advised of the possibility of such damages.

		   9. Accepting Warranty or Additional Liability. While redistributing
		      the Work or Derivative Works thereof, You may choose to offer,
		      and charge a fee for, acceptance of support, warranty, indemnity,
		      or other liability obligations and/or rights consistent with this
		      License. However, in accepting such obligations, You may act only
		      on Your own behalf and on Your sole responsibility, not on behalf
		      of any other Contributor, and only if You agree to indemnify,
		      defend, and hold each Contributor harmless for any liability
		      incurred by, or claims asserted against, such Contributor by reason
		      of your accepting any such warranty or additional liability.




* Authors
    * [openstack-discuss@lists.openstack.org](author)



* Other Licenses
    * **Multi-license:** Apache-2.0 *OR* BSD-2-Clause
    * BSD-3-Clause
    * CC-BY-3.0



* Project URL
    https://launchpad.net/pbr


---
---

#### **plumbum (1.6.7)**


* Licenses
    * MIT
        * Attribution:
        Copyright (c) 2013 Tomer Filiba (tomerfiliba@gmail.com)

		Permission is hereby granted, free of charge, to any person obtaining a copy
		of this software and associated documentation files (the "Software"), to deal
		in the Software without restriction, including without limitation the rights
		to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
		copies of the Software, and to permit persons to whom the Software is
		furnished to do so, subject to the following conditions:

		The above copyright notice and this permission notice shall be included in
		all copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
		THE SOFTWARE.


* Authors
    * [tomerfiliba@gmail.com](author)



* Other Licenses



* Project URL
    https://plumbum.readthedocs.io


---
---

#### **poyo (0.4.2)**


* Licenses
    * MIT
        * Attribution:
        The MIT License (MIT)

		Copyright (c) 2015 Raphael Pierzina

		Permission is hereby granted, free of charge, to any person obtaining a copy
		of this software and associated documentation files (the "Software"), to deal
		in the Software without restriction, including without limitation the rights
		to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
		copies of the Software, and to permit persons to whom the Software is
		furnished to do so, subject to the following conditions:

		The above copyright notice and this permission notice shall be included in all
		copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
		SOFTWARE.




* Authors
    * [raphael@hackebrot.de](author)



* Other Licenses



* Project URL
    https://github.com/hackebrot/poyo


---
---

#### **pp-ez (0.2.0)**


* Licenses
    * BSD-3-Clause
        * Attribution:
        Copyright (c) 2019, pp-ez Contributors . All rights reserved.
		Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
		   1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
		   2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
		   3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


* Authors
    * [david@wolever.net](author)



* Other Licenses



* Project URL
    https://github.com/wolever/pprintpp


---
---

#### **pprintpp (0.4.0)**


* Licenses
    * BSD-3-Clause
        * Attribution:
        Copyright (c) 2019, pprintpp Contributors . All rights reserved.
		Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
		   1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
		   2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
		   3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    * BSD-2-Clause
        * Attribution:
        tl;dr: all code code is licensed under simplified BSD, unless stated otherwise.

		Unless stated otherwise in the source files, all code is copyright 2010 David
		Wolever <david@wolever.net>. All rights reserved.

		Redistribution and use in source and binary forms, with or without
		modification, are permitted provided that the following conditions are met:

		   1. Redistributions of source code must retain the above copyright notice,
		   this list of conditions and the following disclaimer.

		   2. Redistributions in binary form must reproduce the above copyright notice,
		   this list of conditions and the following disclaimer in the documentation
		   and/or other materials provided with the distribution.

		THIS SOFTWARE IS PROVIDED BY <COPYRIGHT HOLDER> ``AS IS'' AND ANY EXPRESS OR
		IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
		MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
		EVENT SHALL <COPYRIGHT HOLDER> OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
		INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
		BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
		DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
		LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
		OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
		ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

		The views and conclusions contained in the software and documentation are those
		of the authors and should not be interpreted as representing official policies,
		either expressed or implied, of David Wolever.



* Authors
    * [david@wolever.net](author)



* Other Licenses



* Project URL
    https://github.com/wolever/pprintpp


---
---

#### **pycparser (2.19)**


* Licenses
    * BSD-3-Clause
        * Attribution:
        pycparser -- A C parser in Python

		Copyright (c) 2008-2017, Eli Bendersky
		All rights reserved.

		Redistribution and use in source and binary forms, with or without modification,
		are permitted provided that the following conditions are met:

		\* Redistributions of source code must retain the above copyright notice, this
		  list of conditions and the following disclaimer.
		\* Redistributions in binary form must reproduce the above copyright notice,
		  this list of conditions and the following disclaimer in the documentation
		  and/or other materials provided with the distribution.
		\* Neither the name of Eli Bendersky nor the names of its contributors may
		  be used to endorse or promote products derived from this software without
		  specific prior written permission.

		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
		ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
		WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
		DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
		LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
		CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
		GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
		HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
		LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
		OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.



* Authors
    * [eliben@gmail.com](author)



* Other Licenses
    * **Multi-license:** BSD-3-Clause *OR* LGPL-3.0-only
    * BSD-2-Clause



* Project URL
    https://github.com/eliben/pycparser


---
---

#### **Pygments (2.4.1)**


* Licenses
    * BSD-2-Clause
        * Attribution:
        Copyright (c) 2006-2019 by the respective authors (see AUTHORS file).
		All rights reserved.

		Redistribution and use in source and binary forms, with or without
		modification, are permitted provided that the following conditions are
		met:

		\* Redistributions of source code must retain the above copyright
		  notice, this list of conditions and the following disclaimer.

		\* Redistributions in binary form must reproduce the above copyright
		  notice, this list of conditions and the following disclaimer in the
		  documentation and/or other materials provided with the distribution.

		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
		"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
		LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
		A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
		OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
		SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
		LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
		DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
		THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
		(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
		OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.



* Authors
    * [georg@python.org](author)



* Other Licenses
    * **Multi-license:** BSD-3-Clause *OR* Apache-2.0
    * BSD-3-Clause
    * MIT
    * public-domain
    * MS-RL
    * GPL-3.0-only



* Project URL
    http://pygments.org/


---
---

#### **pymdown-extensions (6.0)**


* Licenses
    * **Multi-license:** MIT
        * Attribution:
        The MIT License (MIT) (Except where stated below)

		Copyright (c) 2014 - 2018 Isaac Muse

		Permission is hereby granted, free of charge, to any person obtaining a copy
		of this software and associated documentation files (the "Software"), to deal
		in the Software without restriction, including without limitation the rights
		to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
		copies of the Software, and to permit persons to whom the Software is
		furnished to do so, subject to the following conditions:

		The above copyright notice and this permission notice shall be included in all
		copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
		SOFTWARE.

		-----------------------------
		superfences.py is derived from Python Markdown's fenced_code extension.

		Fenced Code Extension for Python Markdown
		 =========================================
		This extension adds Fenced Code Blocks to Python-Markdown.
		See <https://python-markdown.github.io/extensions/fenced_code_blocks/>
		for documentation.
		Original code Copyright 2007-2008 [Waylan Limberg](http://achinghead.com/).
		All changes Copyright 2008-2014 The Python Markdown Project
		License: [BSD](http://www.opensource.org/licenses/bsd-license.php)

		------------------------------
		inlinehilite.py is derived from Python Markdown's codehilite extension.

		CodeHilite Extension for Python-Markdown
		 ========================================
		Adds code/syntax highlighting to standard Python-Markdown code blocks.
		See <https://python-markdown.github.io/extensions/code_hilite/>
		for documentation.
		Original code Copyright 2006-2008 [Waylan Limberg](http://achinghead.com/).
		All changes Copyright 2008-2014 The Python Markdown Project
		License: [BSD](http://www.opensource.org/licenses/bsd-license.php)

		------------------------------
		extrarawhtml.py is a literal copy and paste from Python Markdown's extra extension.
		It basically splits out the raw html markdown parsing into a seprate extension that can
		be used even if it is not desired to use all of 'extra'.

		Python-Markdown Extra Extension
		 ===============================
		See <https://python-markdown.github.io/extensions/extra/>
		for documentation.
		Copyright The Python Markdown Project
		License: [BSD](http://www.opensource.org/licenses/bsd-license.php)

		------------------------------

		gemoji_db.py is generated from Gemoji's source code: https://github.com/github/gemoji.

		Copyright (c) 2013 GitHub, Inc.

		Permission is hereby granted, free of charge, to any person
		obtaining a copy of this software and associated documentation
		files (the "Software"), to deal in the Software without
		restriction, including without limitation the rights to use,
		copy, modify, merge, publish, distribute, sublicense, and/or sell
		copies of the Software, and to permit persons to whom the
		Software is furnished to do so, subject to the following
		conditions:

		The above copyright notice and this permission notice shall be
		included in all copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
		EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
		OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
		NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
		HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
		WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
		FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
		OTHER DEALINGS IN THE SOFTWARE.

		------------------------------

		emoji1_db.py is generated from EmojiOne's source code: https://github.com/Ranks/emojione

		EmojiOne Non-Artwork

		Applies to the Javascript, JSON, PHP, CSS, HTML files, and everything else not covered under the artwork license above.
		License: MIT
		Complete Legal Terms: http://opensource.org/licenses/MIT
		 *OR* BSD-3-Clause
        * Attribution:
        Copyright (c) 2014 - 2018 Isaac Muse . All rights reserved.
		Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
		   1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
		   2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
		   3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    * MIT
        * Attribution:
        The MIT License (MIT) (Except where stated below)

		Copyright (c) 2014 - 2018 Isaac Muse

		Permission is hereby granted, free of charge, to any person obtaining a copy
		of this software and associated documentation files (the "Software"), to deal
		in the Software without restriction, including without limitation the rights
		to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
		copies of the Software, and to permit persons to whom the Software is
		furnished to do so, subject to the following conditions:

		The above copyright notice and this permission notice shall be included in all
		copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
		SOFTWARE.

		-----------------------------
		superfences.py is derived from Python Markdown's fenced_code extension.

		Fenced Code Extension for Python Markdown
		 =========================================
		This extension adds Fenced Code Blocks to Python-Markdown.
		See <https://python-markdown.github.io/extensions/fenced_code_blocks/>
		for documentation.
		Original code Copyright 2007-2008 [Waylan Limberg](http://achinghead.com/).
		All changes Copyright 2008-2014 The Python Markdown Project
		License: [BSD](http://www.opensource.org/licenses/bsd-license.php)

		------------------------------
		inlinehilite.py is derived from Python Markdown's codehilite extension.

		CodeHilite Extension for Python-Markdown
		 ========================================
		Adds code/syntax highlighting to standard Python-Markdown code blocks.
		See <https://python-markdown.github.io/extensions/code_hilite/>
		for documentation.
		Original code Copyright 2006-2008 [Waylan Limberg](http://achinghead.com/).
		All changes Copyright 2008-2014 The Python Markdown Project
		License: [BSD](http://www.opensource.org/licenses/bsd-license.php)

		------------------------------
		extrarawhtml.py is a literal copy and paste from Python Markdown's extra extension.
		It basically splits out the raw html markdown parsing into a seprate extension that can
		be used even if it is not desired to use all of 'extra'.

		Python-Markdown Extra Extension
		 ===============================
		See <https://python-markdown.github.io/extensions/extra/>
		for documentation.
		Copyright The Python Markdown Project
		License: [BSD](http://www.opensource.org/licenses/bsd-license.php)

		------------------------------

		gemoji_db.py is generated from Gemoji's source code: https://github.com/github/gemoji.

		Copyright (c) 2013 GitHub, Inc.

		Permission is hereby granted, free of charge, to any person
		obtaining a copy of this software and associated documentation
		files (the "Software"), to deal in the Software without
		restriction, including without limitation the rights to use,
		copy, modify, merge, publish, distribute, sublicense, and/or sell
		copies of the Software, and to permit persons to whom the
		Software is furnished to do so, subject to the following
		conditions:

		The above copyright notice and this permission notice shall be
		included in all copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
		EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
		OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
		NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
		HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
		WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
		FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
		OTHER DEALINGS IN THE SOFTWARE.

		------------------------------

		emoji1_db.py is generated from EmojiOne's source code: https://github.com/Ranks/emojione

		EmojiOne Non-Artwork

		Applies to the Javascript, JSON, PHP, CSS, HTML files, and everything else not covered under the artwork license above.
		License: MIT
		Complete Legal Terms: http://opensource.org/licenses/MIT



* Authors
    * [Isaac.Muse@gmail.com](author)



* Other Licenses
    * BSD-3-Clause



* Project URL
    https://github.com/facelessuser/pymdown-extensions


---
---

#### **pyOpenSSL (19.0.0)**


* Licenses
    * Apache-2.0
        * Attribution:

		                                 Apache License
		                           Version 2.0, January 2004
		                        http://www.apache.org/licenses/

		   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

		   1. Definitions.

		      "License" shall mean the terms and conditions for use, reproduction,
		      and distribution as defined by Sections 1 through 9 of this document.

		      "Licensor" shall mean the copyright owner or entity authorized by
		      the copyright owner that is granting the License.

		      "Legal Entity" shall mean the union of the acting entity and all
		      other entities that control, are controlled by, or are under common
		      control with that entity. For the purposes of this definition,
		      "control" means (i) the power, direct or indirect, to cause the
		      direction or management of such entity, whether by contract or
		      otherwise, or (ii) ownership of fifty percent (50%) or more of the
		      outstanding shares, or (iii) beneficial ownership of such entity.

		      "You" (or "Your") shall mean an individual or Legal Entity
		      exercising permissions granted by this License.

		      "Source" form shall mean the preferred form for making modifications,
		      including but not limited to software source code, documentation
		      source, and configuration files.

		      "Object" form shall mean any form resulting from mechanical
		      transformation or translation of a Source form, including but
		      not limited to compiled object code, generated documentation,
		      and conversions to other media types.

		      "Work" shall mean the work of authorship, whether in Source or
		      Object form, made available under the License, as indicated by a
		      copyright notice that is included in or attached to the work
		      (an example is provided in the Appendix below).

		      "Derivative Works" shall mean any work, whether in Source or Object
		      form, that is based on (or derived from) the Work and for which the
		      editorial revisions, annotations, elaborations, or other modifications
		      represent, as a whole, an original work of authorship. For the purposes
		      of this License, Derivative Works shall not include works that remain
		      separable from, or merely link (or bind by name) to the interfaces of,
		      the Work and Derivative Works thereof.

		      "Contribution" shall mean any work of authorship, including
		      the original version of the Work and any modifications or additions
		      to that Work or Derivative Works thereof, that is intentionally
		      submitted to Licensor for inclusion in the Work by the copyright owner
		      or by an individual or Legal Entity authorized to submit on behalf of
		      the copyright owner. For the purposes of this definition, "submitted"
		      means any form of electronic, verbal, or written communication sent
		      to the Licensor or its representatives, including but not limited to
		      communication on electronic mailing lists, source code control systems,
		      and issue tracking systems that are managed by, or on behalf of, the
		      Licensor for the purpose of discussing and improving the Work, but
		      excluding communication that is conspicuously marked or otherwise
		      designated in writing by the copyright owner as "Not a Contribution."

		      "Contributor" shall mean Licensor and any individual or Legal Entity
		      on behalf of whom a Contribution has been received by Licensor and
		      subsequently incorporated within the Work.

		   2. Grant of Copyright License. Subject to the terms and conditions of
		      this License, each Contributor hereby grants to You a perpetual,
		      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
		      copyright license to reproduce, prepare Derivative Works of,
		      publicly display, publicly perform, sublicense, and distribute the
		      Work and such Derivative Works in Source or Object form.

		   3. Grant of Patent License. Subject to the terms and conditions of
		      this License, each Contributor hereby grants to You a perpetual,
		      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
		      (except as stated in this section) patent license to make, have made,
		      use, offer to sell, sell, import, and otherwise transfer the Work,
		      where such license applies only to those patent claims licensable
		      by such Contributor that are necessarily infringed by their
		      Contribution(s) alone or by combination of their Contribution(s)
		      with the Work to which such Contribution(s) was submitted. If You
		      institute patent litigation against any entity (including a
		      cross-claim or counterclaim in a lawsuit) alleging that the Work
		      or a Contribution incorporated within the Work constitutes direct
		      or contributory patent infringement, then any patent licenses
		      granted to You under this License for that Work shall terminate
		      as of the date such litigation is filed.

		   4. Redistribution. You may reproduce and distribute copies of the
		      Work or Derivative Works thereof in any medium, with or without
		      modifications, and in Source or Object form, provided that You
		      meet the following conditions:

		      (a) You must give any other recipients of the Work or
		          Derivative Works a copy of this License; and

		      (b) You must cause any modified files to carry prominent notices
		          stating that You changed the files; and

		      (c) You must retain, in the Source form of any Derivative Works
		          that You distribute, all copyright, patent, trademark, and
		          attribution notices from the Source form of the Work,
		          excluding those notices that do not pertain to any part of
		          the Derivative Works; and

		      (d) If the Work includes a "NOTICE" text file as part of its
		          distribution, then any Derivative Works that You distribute must
		          include a readable copy of the attribution notices contained
		          within such NOTICE file, excluding those notices that do not
		          pertain to any part of the Derivative Works, in at least one
		          of the following places: within a NOTICE text file distributed
		          as part of the Derivative Works; within the Source form or
		          documentation, if provided along with the Derivative Works; or,
		          within a display generated by the Derivative Works, if and
		          wherever such third-party notices normally appear. The contents
		          of the NOTICE file are for informational purposes only and
		          do not modify the License. You may add Your own attribution
		          notices within Derivative Works that You distribute, alongside
		          or as an addendum to the NOTICE text from the Work, provided
		          that such additional attribution notices cannot be construed
		          as modifying the License.

		      You may add Your own copyright statement to Your modifications and
		      may provide additional or different license terms and conditions
		      for use, reproduction, or distribution of Your modifications, or
		      for any such Derivative Works as a whole, provided Your use,
		      reproduction, and distribution of the Work otherwise complies with
		      the conditions stated in this License.

		   5. Submission of Contributions. Unless You explicitly state otherwise,
		      any Contribution intentionally submitted for inclusion in the Work
		      by You to the Licensor shall be under the terms and conditions of
		      this License, without any additional terms or conditions.
		      Notwithstanding the above, nothing herein shall supersede or modify
		      the terms of any separate license agreement you may have executed
		      with Licensor regarding such Contributions.

		   6. Trademarks. This License does not grant permission to use the trade
		      names, trademarks, service marks, or product names of the Licensor,
		      except as required for reasonable and customary use in describing the
		      origin of the Work and reproducing the content of the NOTICE file.

		   7. Disclaimer of Warranty. Unless required by applicable law or
		      agreed to in writing, Licensor provides the Work (and each
		      Contributor provides its Contributions) on an "AS IS" BASIS,
		      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
		      implied, including, without limitation, any warranties or conditions
		      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
		      PARTICULAR PURPOSE. You are solely responsible for determining the
		      appropriateness of using or redistributing the Work and assume any
		      risks associated with Your exercise of permissions under this License.

		   8. Limitation of Liability. In no event and under no legal theory,
		      whether in tort (including negligence), contract, or otherwise,
		      unless required by applicable law (such as deliberate and grossly
		      negligent acts) or agreed to in writing, shall any Contributor be
		      liable to You for damages, including any direct, indirect, special,
		      incidental, or consequential damages of any character arising as a
		      result of this License or out of the use or inability to use the
		      Work (including but not limited to damages for loss of goodwill,
		      work stoppage, computer failure or malfunction, or any and all
		      other commercial damages or losses), even if such Contributor
		      has been advised of the possibility of such damages.

		   9. Accepting Warranty or Additional Liability. While redistributing
		      the Work or Derivative Works thereof, You may choose to offer,
		      and charge a fee for, acceptance of support, warranty, indemnity,
		      or other liability obligations and/or rights consistent with this
		      License. However, in accepting such obligations, You may act only
		      on Your own behalf and on Your sole responsibility, not on behalf
		      of any other Contributor, and only if You agree to indemnify,
		      defend, and hold each Contributor harmless for any liability
		      incurred by, or claims asserted against, such Contributor by reason
		      of your accepting any such warranty or additional liability.

		   END OF TERMS AND CONDITIONS

		   APPENDIX: How to apply the Apache License to your work.

		      To apply the Apache License to your work, attach the following
		      boilerplate notice, with the fields enclosed by brackets "[]"
		      replaced with your own identifying information. (Don't include
		      the brackets!)  The text should be enclosed in the appropriate
		      comment syntax for the file format. We also recommend that a
		      file or class name and description of purpose be included on the
		      same "printed page" as the copyright notice for easier
		      identification within third-party archives.

		   Copyright [yyyy] [name of copyright owner]

		   Licensed under the Apache License, Version 2.0 (the "License");
		   you may not use this file except in compliance with the License.
		   You may obtain a copy of the License at

		       http://www.apache.org/licenses/LICENSE-2.0

		   Unless required by applicable law or agreed to in writing, software
		   distributed under the License is distributed on an "AS IS" BASIS,
		   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
		   See the License for the specific language governing permissions and
		   limitations under the License.



* Authors
    * [cryptography-dev@python.org](author)



* Other Licenses
    * **Multi-license:** Apache-2.0 *OR* Python-2.0



* Project URL
    https://pyopenssl.readthedocs.io/


---
---

#### **python-dateutil (2.8.0)**


* Licenses
    * **Multi-license:** BSD-3-Clause
        * Attribution:
        Copyright (c) 2017- Paul Ganssle  . All rights reserved.
		Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
		   1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
		   2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
		   3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. *OR* Apache-2.0
        * Attribution:
        Copyright 2017- Paul Ganssle <paul@ganssle.io>
		Copyright 2017- dateutil contributors (see AUTHORS file)

		   Licensed under the Apache License, Version 2.0 (the "License");
		   you may not use this file except in compliance with the License.
		   You may obtain a copy of the License at

		       http://www.apache.org/licenses/LICENSE-2.0

		   Unless required by applicable law or agreed to in writing, software
		   distributed under the License is distributed on an "AS IS" BASIS,
		   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
		   See the License for the specific language governing permissions and
		   limitations under the License.

		The above license applies to all contributions after 2017-12-01, as well as
		all contributions that have been re-licensed (see AUTHORS file for the list of
		contributors who have re-licensed their code).
		--------------------------------------------------------------------------------
		dateutil - Extensions to the standard Python datetime module.

		Copyright (c) 2003-2011 - Gustavo Niemeyer <gustavo@niemeyer.net>
		Copyright (c) 2012-2014 - Tomi Pieviläinen <tomi.pievilainen@iki.fi>
		Copyright (c) 2014-2016 - Yaron de Leeuw <me@jarondl.net>
		Copyright (c) 2015-     - Paul Ganssle <paul@ganssle.io>
		Copyright (c) 2015-     - dateutil contributors (see AUTHORS file)

		All rights reserved.

		Redistribution and use in source and binary forms, with or without
		modification, are permitted provided that the following conditions are met:

		    * Redistributions of source code must retain the above copyright notice,
		      this list of conditions and the following disclaimer.
		    * Redistributions in binary form must reproduce the above copyright notice,
		      this list of conditions and the following disclaimer in the documentation
		      and/or other materials provided with the distribution.
		    * Neither the name of the copyright holder nor the names of its
		      contributors may be used to endorse or promote products derived from
		      this software without specific prior written permission.

		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
		"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
		LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
		A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
		CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
		EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
		PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
		PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
		LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
		NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
		SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

		The above BSD License Applies to all code, even that also covered by Apache 2.0.


* Authors
    * [gustavo@niemeyer.net](author)



* Other Licenses
    * BSD-3-Clause
    * **Multi-license:** BSD-3-Clause *OR* Apache-2.0 *OR* Python-2.0



* Project URL
    https://dateutil.readthedocs.org


---
---

#### **python-slugify (3.0.2)**


* Licenses
    * MIT
        * Attribution:
        The MIT License

		Copyright (c) Val Neekman @ Neekware Inc. http://neekware.com

		Permission is hereby granted, free of charge, to any person obtaining a copy
		of this software and associated documentation files (the "Software"), to deal
		in the Software without restriction, including without limitation the rights
		to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
		copies of the Software, and to permit persons to whom the Software is
		furnished to do so, subject to the following conditions:

		The above copyright notice and this permission notice shall be included in
		all copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
		THE SOFTWARE.



* Authors
    * [info@neekware.com](author)



* Other Licenses
    * **Multi-license:** GPL-3.0-only *OR* MIT



* Project URL
    https://github.com/un33k/python-slugify


---
---

#### **requests (2.22.0)**


* Licenses
    * Apache-2.0
        * Attribution:
        Copyright 2018 Kenneth Reitz

		   Licensed under the Apache License, Version 2.0 (the "License");
		   you may not use this file except in compliance with the License.
		   You may obtain a copy of the License at

		       https://www.apache.org/licenses/LICENSE-2.0

		   Unless required by applicable law or agreed to in writing, software
		   distributed under the License is distributed on an "AS IS" BASIS,
		   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
		   See the License for the specific language governing permissions and
		   limitations under the License.



* Authors
    * [me@kennethreitz.org](author)



* Other Licenses



* Project URL
    http://python-requests.org


---
---

#### **ruamel.yaml (0.15.96)**


* Licenses
    * MIT
        * Attribution:
         The MIT License (MIT)

		 Copyright (c) 2014-2019 Anthon van der Neut, Ruamel bvba

		 Permission is hereby granted, free of charge, to any person obtaining a copy
		 of this software and associated documentation files (the "Software"), to deal
		 in the Software without restriction, including without limitation the rights
		 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
		 copies of the Software, and to permit persons to whom the Software is
		 furnished to do so, subject to the following conditions:

		 The above copyright notice and this permission notice shall be included in
		 all copies or substantial portions of the Software.

		 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
		 SOFTWARE.



* Authors
    * [a.van.der.neut@ruamel.eu](author)



* Other Licenses



* Project URL
    https://bitbucket.org/ruamel/yaml


---
---

#### **ruamel.yaml.jinja2 (0.2.2)**


* Licenses
    * MIT
        * Attribution:
         The MIT License (MIT)

		 Copyright (c) 2017 Anthon van der Neut, Ruamel bvba

		 Permission is hereby granted, free of charge, to any person obtaining a copy
		 of this software and associated documentation files (the "Software"), to deal
		 in the Software without restriction, including without limitation the rights
		 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
		 copies of the Software, and to permit persons to whom the Software is
		 furnished to do so, subject to the following conditions:

		 The above copyright notice and this permission notice shall be included in
		 all copies or substantial portions of the Software.

		 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
		 SOFTWARE.



* Authors
    * [a.van.der.neut@ruamel.eu](author)



* Other Licenses



* Project URL
    https://bitbucket.org/ruamel/yaml.jinja2


---
---

#### **shellingham (1.3.1)**


* Licenses
    * MIT
        * Attribution:
        Copyright (c) 2018, Tzu-ping Chung <uranusjr@gmail.com>

		Permission to use, copy, modify, and distribute this software for any
		purpose with or without fee is hereby granted, provided that the above
		copyright notice and this permission notice appear in all copies.

		THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
		WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
		MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
		ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
		WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
		ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
		OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.



* Authors
    * [uranusjr@gmail.com](author)



* Other Licenses
    * ISC
    * BSD-3-Clause



* Project URL
    https://github.com/sarugaku/shellingham


---
---

#### **six (1.12.0)**


* Licenses
    * MIT
        * Attribution:
        Copyright (c) 2010-2018 Benjamin Peterson

		Permission is hereby granted, free of charge, to any person obtaining a copy of
		this software and associated documentation files (the "Software"), to deal in
		the Software without restriction, including without limitation the rights to
		use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
		the Software, and to permit persons to whom the Software is furnished to do so,
		subject to the following conditions:

		The above copyright notice and this permission notice shall be included in all
		copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
		FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
		COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
		IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
		CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



* Authors
    * [benjamin@python.org](author)



* Other Licenses



* Project URL
    http://pypi.python.org/pypi/six/


---
---

#### **spinners (0.0.23)**


* Licenses
    * MIT
        * Attribution:
        MIT License

		Copyright (c) 2017 Manraj Singh

		Permission is hereby granted, free of charge, to any person obtaining a copy
		of this software and associated documentation files (the "Software"), to deal
		in the Software without restriction, including without limitation the rights
		to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
		copies of the Software, and to permit persons to whom the Software is
		furnished to do so, subject to the following conditions:

		The above copyright notice and this permission notice shall be included in all
		copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
		SOFTWARE.



* Authors
    * [manrajsinghgrover@gmail.com](author)



* Other Licenses



* Project URL
    https://github.com/ManrajGrover/py-spinners


---
---

#### **stevedore (1.30.1)**


* Licenses
    * Apache-2.0
        * Attribution:

		                                 Apache License
		                           Version 2.0, January 2004
		                        http://www.apache.org/licenses/

		   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION

		   1. Definitions.

		      "License" shall mean the terms and conditions for use, reproduction,
		      and distribution as defined by Sections 1 through 9 of this document.

		      "Licensor" shall mean the copyright owner or entity authorized by
		      the copyright owner that is granting the License.

		      "Legal Entity" shall mean the union of the acting entity and all
		      other entities that control, are controlled by, or are under common
		      control with that entity. For the purposes of this definition,
		      "control" means (i) the power, direct or indirect, to cause the
		      direction or management of such entity, whether by contract or
		      otherwise, or (ii) ownership of fifty percent (50%) or more of the
		      outstanding shares, or (iii) beneficial ownership of such entity.

		      "You" (or "Your") shall mean an individual or Legal Entity
		      exercising permissions granted by this License.

		      "Source" form shall mean the preferred form for making modifications,
		      including but not limited to software source code, documentation
		      source, and configuration files.

		      "Object" form shall mean any form resulting from mechanical
		      transformation or translation of a Source form, including but
		      not limited to compiled object code, generated documentation,
		      and conversions to other media types.

		      "Work" shall mean the work of authorship, whether in Source or
		      Object form, made available under the License, as indicated by a
		      copyright notice that is included in or attached to the work
		      (an example is provided in the Appendix below).

		      "Derivative Works" shall mean any work, whether in Source or Object
		      form, that is based on (or derived from) the Work and for which the
		      editorial revisions, annotations, elaborations, or other modifications
		      represent, as a whole, an original work of authorship. For the purposes
		      of this License, Derivative Works shall not include works that remain
		      separable from, or merely link (or bind by name) to the interfaces of,
		      the Work and Derivative Works thereof.

		      "Contribution" shall mean any work of authorship, including
		      the original version of the Work and any modifications or additions
		      to that Work or Derivative Works thereof, that is intentionally
		      submitted to Licensor for inclusion in the Work by the copyright owner
		      or by an individual or Legal Entity authorized to submit on behalf of
		      the copyright owner. For the purposes of this definition, "submitted"
		      means any form of electronic, verbal, or written communication sent
		      to the Licensor or its representatives, including but not limited to
		      communication on electronic mailing lists, source code control systems,
		      and issue tracking systems that are managed by, or on behalf of, the
		      Licensor for the purpose of discussing and improving the Work, but
		      excluding communication that is conspicuously marked or otherwise
		      designated in writing by the copyright owner as "Not a Contribution."

		      "Contributor" shall mean Licensor and any individual or Legal Entity
		      on behalf of whom a Contribution has been received by Licensor and
		      subsequently incorporated within the Work.

		   2. Grant of Copyright License. Subject to the terms and conditions of
		      this License, each Contributor hereby grants to You a perpetual,
		      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
		      copyright license to reproduce, prepare Derivative Works of,
		      publicly display, publicly perform, sublicense, and distribute the
		      Work and such Derivative Works in Source or Object form.

		   3. Grant of Patent License. Subject to the terms and conditions of
		      this License, each Contributor hereby grants to You a perpetual,
		      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
		      (except as stated in this section) patent license to make, have made,
		      use, offer to sell, sell, import, and otherwise transfer the Work,
		      where such license applies only to those patent claims licensable
		      by such Contributor that are necessarily infringed by their
		      Contribution(s) alone or by combination of their Contribution(s)
		      with the Work to which such Contribution(s) was submitted. If You
		      institute patent litigation against any entity (including a
		      cross-claim or counterclaim in a lawsuit) alleging that the Work
		      or a Contribution incorporated within the Work constitutes direct
		      or contributory patent infringement, then any patent licenses
		      granted to You under this License for that Work shall terminate
		      as of the date such litigation is filed.

		   4. Redistribution. You may reproduce and distribute copies of the
		      Work or Derivative Works thereof in any medium, with or without
		      modifications, and in Source or Object form, provided that You
		      meet the following conditions:

		      (a) You must give any other recipients of the Work or
		          Derivative Works a copy of this License; and

		      (b) You must cause any modified files to carry prominent notices
		          stating that You changed the files; and

		      (c) You must retain, in the Source form of any Derivative Works
		          that You distribute, all copyright, patent, trademark, and
		          attribution notices from the Source form of the Work,
		          excluding those notices that do not pertain to any part of
		          the Derivative Works; and

		      (d) If the Work includes a "NOTICE" text file as part of its
		          distribution, then any Derivative Works that You distribute must
		          include a readable copy of the attribution notices contained
		          within such NOTICE file, excluding those notices that do not
		          pertain to any part of the Derivative Works, in at least one
		          of the following places: within a NOTICE text file distributed
		          as part of the Derivative Works; within the Source form or
		          documentation, if provided along with the Derivative Works; or,
		          within a display generated by the Derivative Works, if and
		          wherever such third-party notices normally appear. The contents
		          of the NOTICE file are for informational purposes only and
		          do not modify the License. You may add Your own attribution
		          notices within Derivative Works that You distribute, alongside
		          or as an addendum to the NOTICE text from the Work, provided
		          that such additional attribution notices cannot be construed
		          as modifying the License.

		      You may add Your own copyright statement to Your modifications and
		      may provide additional or different license terms and conditions
		      for use, reproduction, or distribution of Your modifications, or
		      for any such Derivative Works as a whole, provided Your use,
		      reproduction, and distribution of the Work otherwise complies with
		      the conditions stated in this License.

		   5. Submission of Contributions. Unless You explicitly state otherwise,
		      any Contribution intentionally submitted for inclusion in the Work
		      by You to the Licensor shall be under the terms and conditions of
		      this License, without any additional terms or conditions.
		      Notwithstanding the above, nothing herein shall supersede or modify
		      the terms of any separate license agreement you may have executed
		      with Licensor regarding such Contributions.

		   6. Trademarks. This License does not grant permission to use the trade
		      names, trademarks, service marks, or product names of the Licensor,
		      except as required for reasonable and customary use in describing the
		      origin of the Work and reproducing the content of the NOTICE file.

		   7. Disclaimer of Warranty. Unless required by applicable law or
		      agreed to in writing, Licensor provides the Work (and each
		      Contributor provides its Contributions) on an "AS IS" BASIS,
		      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
		      implied, including, without limitation, any warranties or conditions
		      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
		      PARTICULAR PURPOSE. You are solely responsible for determining the
		      appropriateness of using or redistributing the Work and assume any
		      risks associated with Your exercise of permissions under this License.

		   8. Limitation of Liability. In no event and under no legal theory,
		      whether in tort (including negligence), contract, or otherwise,
		      unless required by applicable law (such as deliberate and grossly
		      negligent acts) or agreed to in writing, shall any Contributor be
		      liable to You for damages, including any direct, indirect, special,
		      incidental, or consequential damages of any character arising as a
		      result of this License or out of the use or inability to use the
		      Work (including but not limited to damages for loss of goodwill,
		      work stoppage, computer failure or malfunction, or any and all
		      other commercial damages or losses), even if such Contributor
		      has been advised of the possibility of such damages.

		   9. Accepting Warranty or Additional Liability. While redistributing
		      the Work or Derivative Works thereof, You may choose to offer,
		      and charge a fee for, acceptance of support, warranty, indemnity,
		      or other liability obligations and/or rights consistent with this
		      License. However, in accepting such obligations, You may act only
		      on Your own behalf and on Your sole responsibility, not on behalf
		      of any other Contributor, and only if You agree to indemnify,
		      defend, and hold each Contributor harmless for any liability
		      incurred by, or claims asserted against, such Contributor by reason
		      of your accepting any such warranty or additional liability.

		   END OF TERMS AND CONDITIONS

		   APPENDIX: How to apply the Apache License to your work.

		      To apply the Apache License to your work, attach the following
		      boilerplate notice, with the fields enclosed by brackets "[]"
		      replaced with your own identifying information. (Don't include
		      the brackets!)  The text should be enclosed in the appropriate
		      comment syntax for the file format. We also recommend that a
		      file or class name and description of purpose be included on the
		      same "printed page" as the copyright notice for easier
		      identification within third-party archives.

		   Copyright [yyyy] [name of copyright owner]

		   Licensed under the Apache License, Version 2.0 (the "License");
		   you may not use this file except in compliance with the License.
		   You may obtain a copy of the License at

		       http://www.apache.org/licenses/LICENSE-2.0

		   Unless required by applicable law or agreed to in writing, software
		   distributed under the License is distributed on an "AS IS" BASIS,
		   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
		   See the License for the specific language governing permissions and
		   limitations under the License.



* Authors
    * [openstack-discuss@lists.openstack.org](author)



* Other Licenses



* Project URL
    http://docs.openstack.org/developer/stevedore/


---
---

#### **tabulate (0.8.3)**


* Licenses
    * MIT
        * Attribution:
        Copyright (c) 2011-2017 Sergey Astanin

		Permission is hereby granted, free of charge, to any person obtaining
		a copy of this software and associated documentation files (the
		"Software"), to deal in the Software without restriction, including
		without limitation the rights to use, copy, modify, merge, publish,
		distribute, sublicense, and/or sell copies of the Software, and to
		permit persons to whom the Software is furnished to do so, subject to
		the following conditions:

		The above copyright notice and this permission notice shall be
		included in all copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
		EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
		MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
		NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
		LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
		OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
		WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



* Authors
    * [s.astanin@gmail.com](author)



* Other Licenses



* Project URL
    https://bitbucket.org/astanin/python-tabulate


---
---

#### **termcolor (1.1.0)**


* Licenses
    * MIT
        * Attribution:
        Copyright (c) 2019, termcolor Contributors
		Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
		The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


* Authors
    * [konstantin.lepa@gmail.com](author)



* Other Licenses



* Project URL
    http://pypi.python.org/pypi/termcolor


---
---

#### **text-unidecode (1.2)**


* Licenses
    * **Multi-license:** Artistic-1.0
        * Attribution:
        Preamble
		The intent of this document is to state the conditions under which a Package may be copied, such that the Copyright Holder maintains some semblance of artistic control over the development of the package, while giving the users of the package the right to use and distribute the Package in a more-or-less customary fashion, plus the right to make reasonable modifications.
		Definitions:
		"Package" refers to the collection of files distributed by the Copyright Holder, and derivatives of that collection of files created through textual modification.
		"Standard Version" refers to such a Package if it has not been modified, or has been modified in accordance with the wishes of the Copyright Holder.
		"Copyright Holder" is whoever is named in the copyright or copyrights for the package.
		"You" is you, if you're thinking about copying or distributing this Package.
		"Reasonable copying fee" is whatever you can justify on the basis of media cost, duplication charges, time of people involved, and so on. (You will not be required to justify it to the Copyright Holder, but only to the computing community at large as a market that must bear the fee.)
		"Freely Available" means that no fee is charged for the item itself, though there may be fees involved in handling the item. It also means that recipients of the item may redistribute it under the same conditions they received it.
		   1. You may make and give away verbatim copies of the source form of the Standard Version of this Package without restriction, provided that you duplicate all of the original copyright notices and associated disclaimers.
		   2. You may apply bug fixes, portability fixes and other modifications derived from the Public Domain or from the Copyright Holder. A Package modified in such a way shall still be considered the Standard Version.
		   3. You may otherwise modify your copy of this Package in any way, provided that you insert a prominent notice in each changed file stating how and when you changed that file, and provided that you do at least ONE of the following:
		      a) place your modifications in the Public Domain or otherwise make them Freely Available, such as by posting said modifications to Usenet or an equivalent medium, or placing the modifications on a major archive site such as ftp.uu.net, or by allowing the Copyright Holder to include your modifications in the Standard Version of the Package.
		      b) use the modified Package only within your corporation or organization.
		      c) rename any non-standard executables so the names do not conflict with standard executables, which must also be provided, and provide a separate manual page for each non-standard executable that clearly documents how it differs from the Standard Version.
		      d) make other distribution arrangements with the Copyright Holder.
		   4. You may distribute the programs of this Package in object code or executable form, provided that you do at least ONE of the following:
		      a) distribute a Standard Version of the executables and library files, together with instructions (in the manual page or equivalent) on where to get the Standard Version.
		      b) accompany the distribution with the machine-readable source of the Package with your modifications.
		      c) accompany any non-standard executables with their corresponding Standard Version executables, giving the non-standard executables non-standard names, and clearly documenting the differences in manual pages (or equivalent), together with instructions on where to get the Standard Version.
		      d) make other distribution arrangements with the Copyright Holder.
		   5. You may charge a reasonable copying fee for any distribution of this Package. You may charge any fee you choose for support of this Package. You may not charge a fee for this Package itself. However, you may distribute this Package in aggregate with other (possibly commercial) programs as part of a larger (possibly commercial) software distribution provided that you do not advertise this Package as a product of your own.
		   6. The scripts and library files supplied as input to or produced as output from the programs of this Package do not automatically fall under the copyright of this Package, but belong to whomever generated them, and may be sold commercially, and may be aggregated with this Package.
		   7. C or perl subroutines supplied by you and linked into this Package shall not be considered part of this Package.
		   8. The name of the Copyright Holder may not be used to endorse or promote products derived from this software without specific prior written permission.
		   9. THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE. *OR* Artistic-2.0
        * Attribution:
        Copyright (c) 2000-2006, The Perl Foundation.
		Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.
		Preamble
		This license establishes the terms under which a given free software Package may be copied, modified, distributed, and/or redistributed. The intent is that the Copyright Holder maintains some artistic control over the development of that Package while still keeping the Package available as open source and free software.
		You are always permitted to make arrangements wholly outside of this license directly with the Copyright Holder of a given Package. If the terms of this license do not permit the full use that you propose to make of the Package, you should contact the Copyright Holder and seek a different licensing arrangement.
		Definitions

		   "Copyright Holder" means the individual(s) or organization(s) named in the copyright notice for the entire Package.

		   "Contributor" means any party that has contributed code or other material to the Package, in accordance with the Copyright Holder's procedures.

		   "You" and "your" means any person who would like to copy, distribute, or modify the Package.

		   "Package" means the collection of files distributed by the Copyright Holder, and derivatives of that collection and/or of those files. A given Package may consist of either the Standard Version, or a Modified Version.

		   "Distribute" means providing a copy of the Package or making it accessible to anyone else, or in the case of a company or organization, to others outside of your company or organization.

		   "Distributor Fee" means any fee that you charge for Distributing this Package or providing support for this Package to another party. It does not mean licensing fees.

		   "Standard Version" refers to the Package if it has not been modified, or has been modified only in ways explicitly requested by the Copyright Holder.

		   "Modified Version" means the Package, if it has been changed, and such changes were not explicitly requested by the Copyright Holder.

		   "Original License" means this Artistic License as Distributed with the Standard Version of the Package, in its current version or as it may be modified by The Perl Foundation in the future.

		   "Source" form means the source code, documentation source, and configuration files for the Package.

		   "Compiled" form means the compiled bytecode, object code, binary, or any other form resulting from mechanical transformation or translation of the Source form.
		Permission for Use and Modification Without Distribution
		   (1) You are permitted to use the Standard Version and create and use Modified Versions for any purpose without restriction, provided that you do not Distribute the Modified Version.
		Permissions for Redistribution of the Standard Version
		   (2) You may Distribute verbatim copies of the Source form of the Standard Version of this Package in any medium without restriction, either gratis or for a Distributor Fee, provided that you duplicate all of the original copyright notices and associated disclaimers. At your discretion, such verbatim copies may or may not include a Compiled form of the Package.
		   (3) You may apply any bug fixes, portability changes, and other modifications made available from the Copyright Holder. The resulting Package will still be considered the Standard Version, and as such will be subject to the Original License.
		Distribution of Modified Versions of the Package as Source
		   (4) You may Distribute your Modified Version as Source (either gratis or for a Distributor Fee, and with or without a Compiled form of the Modified Version) provided that you clearly document how it differs from the Standard Version, including, but not limited to, documenting any non-standard features, executables, or modules, and provided that you do at least ONE of the following:
		      (a) make the Modified Version available to the Copyright Holder of the Standard Version, under the Original License, so that the Copyright Holder may include your modifications in the Standard Version.
		      (b) ensure that installation of your Modified Version does not prevent the user installing or running the Standard Version. In addition, the Modified Version must bear a name that is different from the name of the Standard Version.
		      (c) allow anyone who receives a copy of the Modified Version to make the Source form of the Modified Version available to others under
		         (i) the Original License or
		         (ii) a license that permits the licensee to freely copy, modify and redistribute the Modified Version using the same licensing terms that apply to the copy that the licensee received, and requires that the Source form of the Modified Version, and of any works derived from it, be made freely available in that license fees are prohibited but Distributor Fees are allowed.
		Distribution of Compiled Forms of the Standard Version or Modified Versions without the Source
		   (5) You may Distribute Compiled forms of the Standard Version without the Source, provided that you include complete instructions on how to get the Source of the Standard Version. Such instructions must be valid at the time of your distribution. If these instructions, at any time while you are carrying out such distribution, become invalid, you must provide new instructions on demand or cease further distribution. If you provide valid instructions or cease distribution within thirty days after you become aware that the instructions are invalid, then you do not forfeit any of your rights under this license.
		   (6) You may Distribute a Modified Version in Compiled form without the Source, provided that you comply with Section 4 with respect to the Source of the Modified Version.
		Aggregating or Linking the Package
		   (7) You may aggregate the Package (either the Standard Version or Modified Version) with other packages and Distribute the resulting aggregation provided that you do not charge a licensing fee for the Package. Distributor Fees are permitted, and licensing fees for other components in the aggregation are permitted. The terms of this license apply to the use and Distribution of the Standard or Modified Versions as included in the aggregation.
		   (8) You are permitted to link Modified and Standard Versions with other works, to embed the Package in a larger work of your own, or to build stand-alone binary or bytecode versions of applications that include the Package, and Distribute the result without restriction, provided the result does not expose a direct interface to the Package.
		Items That are Not Considered Part of a Modified Version
		   (9) Works (including, but not limited to, modules and scripts) that merely extend or make use of the Package, do not, by themselves, cause the Package to be a Modified Version. In addition, such works are not considered parts of the Package itself, and are not subject to the terms of this license.
		General Provisions
		   (10) Any use, modification, and distribution of the Standard or Modified Versions is governed by this Artistic License. By using, modifying or distributing the Package, you accept this license. Do not use, modify, or distribute the Package, if you do not accept this license.
		   (11) If your Modified Version has been derived from a Modified Version made by someone other than you, you are nevertheless required to ensure that your Modified Version complies with the requirements of this license.
		   (12) This license does not grant you the right to use any trademark, service mark, tradename, or logo of the Copyright Holder.
		   (13) This license includes the non-exclusive, worldwide, free-of-charge patent license to make, have made, use, offer to sell, sell, import and otherwise transfer the Package with respect to any patent claims licensable by the Copyright Holder that are necessarily infringed by the Package. If you institute patent litigation (including a cross-claim or counterclaim) against any party alleging that the Package constitutes direct or contributory patent infringement, then this Artistic License to you shall terminate on the date that such litigation is filed.
		   (14) Disclaimer of Warranty:
		   THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER AND CONTRIBUTORS "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


* Authors
    * [kmike84@gmail.com](author)



* Other Licenses
    * **Multi-license:** Artistic-1.0 *OR* GPL-2.0-only
    * Artistic-1.0



* Project URL
    https://github.com/kmike/text-unidecode/


---
---

#### **toml (0.10.0)**


* Licenses
    * MIT
        * Attribution:
        The MIT License

		Copyright 2013-2018 William Pearson
		Copyright 2015-2016 Julien Enselme
		Copyright 2016 Google Inc.
		Copyright 2017 Samuel Vasko
		Copyright 2017 Nate Prewitt
		Copyright 2017 Jack Evans

		Permission is hereby granted, free of charge, to any person obtaining a copy
		of this software and associated documentation files (the "Software"), to deal
		in the Software without restriction, including without limitation the rights
		to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
		copies of the Software, and to permit persons to whom the Software is
		furnished to do so, subject to the following conditions:

		The above copyright notice and this permission notice shall be included in
		all copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
		THE SOFTWARE.


* Authors
    * [uiri@xqz.ca](author)



* Other Licenses



* Project URL
    https://github.com/uiri/toml


---
---

#### **tqdm (4.32.1)**


* Licenses
    * **Multi-license:** MIT
        * Attribution:
        `tqdm` is a product of collaborative work.
		Unless otherwise stated, all authors (see commit logs) retain copyright
		for their respective work, and release the work under the MIT licence
		(text below).

		Exceptions or notable authors are listed below
		in reverse chronological order:

		\* files: *
		  MPLv2.0 2015-2019 (c) Casper da Costa-Luis
		  [casperdcl](https://github.com/casperdcl).
		\* files: tqdm/_tqdm.py
		  MIT 2016 (c) [PR #96] on behalf of Google Inc.
		\* files: tqdm/_tqdm.py setup.py README.rst MANIFEST.in .gitignore
		  MIT 2013 (c) Noam Yorav-Raphael, original author.

		[PR #96]: https://github.com/tqdm/tqdm/pull/96


		Mozilla Public Licence (MPL) v. 2.0 - Exhibit A
		-----------------------------------------------

		This Source Code Form is subject to the terms of the
		Mozilla Public License, v. 2.0.
		If a copy of the MPL was not distributed with this file,
		You can obtain one at https://mozilla.org/MPL/2.0/.


		MIT License (MIT)
		-----------------

		Copyright (c) 2013 noamraph

		Permission is hereby granted, free of charge, to any person obtaining a copy of
		this software and associated documentation files (the "Software"), to deal in
		the Software without restriction, including without limitation the rights to
		use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
		the Software, and to permit persons to whom the Software is furnished to do so,
		subject to the following conditions:

		The above copyright notice and this permission notice shall be included in all
		copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
		FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
		COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
		IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
		CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
		 *OR* MPL-2.0
        * Attribution:
        1\. Definitions
		      1.1. "Contributor" means each individual or legal entity that creates, contributes to the creation of, or owns Covered Software.
		      1.2. "Contributor Version" means the combination of the Contributions of others (if any) used by a Contributor and that particular Contributor's Contribution.
		      1.3. "Contribution" means Covered Software of a particular Contributor.
		      1.4. "Covered Software" means Source Code Form to which the initial Contributor has attached the notice in Exhibit A, the Executable Form of such Source Code Form, and Modifications of such Source Code Form, in each case including portions thereof.
		      1.5. "Incompatible With Secondary Licenses" means
		         (a) that the initial Contributor has attached the notice described in Exhibit B to the Covered Software; or
		         (b) that the Covered Software was made available under the terms of version 1.1 or earlier of the License, but not also under the terms of a Secondary License.
		      1.6. "Executable Form" means any form of the work other than Source Code Form.
		      1.7. "Larger Work" means a work that combines Covered Software with other material, in a separate file or files, that is not Covered Software.
		      1.8. "License" means this document.
		      1.9. "Licensable" means having the right to grant, to the maximum extent possible, whether at the time of the initial grant or subsequently, any and all of the rights conveyed by this License.
		      1.10. "Modifications" means any of the following:
		         (a) any file in Source Code Form that results from an addition to, deletion from, or modification of the contents of Covered Software; or
		         (b) any new file in Source Code Form that contains any Covered Software.
		      1.11. "Patent Claims" of a Contributor means any patent claim(s), including without limitation, method, process, and apparatus claims, in any patent Licensable by such Contributor that would be infringed, but for the grant of the License, by the making, using, selling, offering for sale, having made, import, or transfer of either its Contributions or its Contributor Version.
		      1.12. "Secondary License" means either the GNU General Public License, Version 2.0, the GNU Lesser General Public License, Version 2.1, the GNU Affero General Public License, Version 3.0, or any later versions of those licenses.
		      1.13. "Source Code Form" means the form of the work preferred for making modifications.
		      1.14. "You" (or "Your") means an individual or a legal entity exercising rights under this License. For legal entities, "You" includes any entity that controls, is controlled by, or is under common control with You. For purposes of this definition, "control" means (a) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (b) ownership of more than fifty percent (50%) of the outstanding shares or beneficial ownership of such entity.
		   2. License Grants and Conditions
		      2.1. Grants
		      Each Contributor hereby grants You a world-wide, royalty-free, non-exclusive license:
		         (a) under intellectual property rights (other than patent or trademark) Licensable by such Contributor to use, reproduce, make available, modify, display, perform, distribute, and otherwise exploit its Contributions, either on an unmodified basis, with Modifications, or as part of a Larger Work; and
		         (b) under Patent Claims of such Contributor to make, use, sell, offer for sale, have made, import, and otherwise transfer either its Contributions or its Contributor Version.
		      2.2. Effective Date
		      The licenses granted in Section 2.1 with respect to any Contribution become effective for each Contribution on the date the Contributor first distributes such Contribution.
		      2.3. Limitations on Grant Scope
		      The licenses granted in this Section 2 are the only rights granted under this License. No additional rights or licenses will be implied from the distribution or licensing of Covered Software under this License. Notwithstanding Section 2.1(b) above, no patent license is granted by a Contributor:
		         (a) for any code that a Contributor has removed from Covered Software; or
		         (b) for infringements caused by: (i) Your and any other third party's modifications of Covered Software, or (ii) the combination of its Contributions with other software (except as part of its Contributor Version); or
		         (c) under Patent Claims infringed by Covered Software in the absence of its Contributions.
		      This License does not grant any rights in the trademarks, service marks, or logos of any Contributor (except as may be necessary to comply with the notice requirements in Section 3.4).
		      2.4. Subsequent Licenses
		      No Contributor makes additional grants as a result of Your choice to distribute the Covered Software under a subsequent version of this License (see Section 10.2) or under the terms of a Secondary License (if permitted under the terms of Section 3.3).
		      2.5. Representation
		      Each Contributor represents that the Contributor believes its Contributions are its original creation(s) or it has sufficient rights to grant the rights to its Contributions conveyed by this License.
		      2.6. Fair Use
		      This License is not intended to limit any rights You have under applicable copyright doctrines of fair use, fair dealing, or other equivalents.
		      2.7. Conditions
		      Sections 3.1, 3.2, 3.3, and 3.4 are conditions of the licenses granted in Section 2.1.
		   3. Responsibilities
		      3.1. Distribution of Source Form
		      All distribution of Covered Software in Source Code Form, including any Modifications that You create or to which You contribute, must be under the terms of this License. You must inform recipients that the Source Code Form of the Covered Software is governed by the terms of this License, and how they can obtain a copy of this License. You may not attempt to alter or restrict the recipients' rights in the Source Code Form.
		      3.2. Distribution of Executable Form
		      If You distribute Covered Software in Executable Form then:
		         (a) such Covered Software must also be made available in Source Code Form, as described in Section 3.1, and You must inform recipients of the Executable Form how they can obtain a copy of such Source Code Form by reasonable means in a timely manner, at a charge no more than the cost of distribution to the recipient; and
		         (b) You may distribute such Executable Form under the terms of this License, or sublicense it under different terms, provided that the license for the Executable Form does not attempt to limit or alter the recipients' rights in the Source Code Form under this License.
		      3.3. Distribution of a Larger Work
		      You may create and distribute a Larger Work under terms of Your choice, provided that You also comply with the requirements of this License for the Covered Software. If the Larger Work is a combination of Covered Software with a work governed by one or more Secondary Licenses, and the Covered Software is not Incompatible With Secondary Licenses, this License permits You to additionally distribute such Covered Software under the terms of such Secondary License(s), so that the recipient of the Larger Work may, at their option, further distribute the Covered Software under the terms of either this License or such Secondary License(s).
		      3.4. Notices
		      You may not remove or alter the substance of any license notices (including copyright notices, patent notices, disclaimers of warranty, or limitations of liability) contained within the Source Code Form of the Covered Software, except that You may alter any license notices to the extent required to remedy known factual inaccuracies.
		      3.5. Application of Additional Terms
		      You may choose to offer, and to charge a fee for, warranty, support, indemnity or liability obligations to one or more recipients of Covered Software. However, You may do so only on Your own behalf, and not on behalf of any Contributor. You must make it absolutely clear that any such warranty, support, indemnity, or liability obligation is offered by You alone, and You hereby agree to indemnify every Contributor for any liability incurred by such Contributor as a result of warranty, support, indemnity or liability terms You offer. You may include additional disclaimers of warranty and limitations of liability specific to any jurisdiction.
		   4. Inability to Comply Due to Statute or Regulation
		   If it is impossible for You to comply with any of the terms of this License with respect to some or all of the Covered Software due to statute, judicial order, or regulation then You must: (a) comply with the terms of this License to the maximum extent possible; and (b) describe the limitations and the code they affect. Such description must be placed in a text file included with all distributions of the Covered Software under this License. Except to the extent prohibited by statute or regulation, such description must be sufficiently detailed for a recipient of ordinary skill to be able to understand it.
		   5. Termination
		      5.1. The rights granted under this License will terminate automatically if You fail to comply with any of its terms. However, if You become compliant, then the rights granted under this License from a particular Contributor are reinstated (a) provisionally, unless and until such Contributor explicitly and finally terminates Your grants, and (b) on an ongoing basis, if such Contributor fails to notify You of the non-compliance by some reasonable means prior to 60 days after You have come back into compliance. Moreover, Your grants from a particular Contributor are reinstated on an ongoing basis if such Contributor notifies You of the non-compliance by some reasonable means, this is the first time You have received notice of non-compliance with this License from such Contributor, and You become compliant prior to 30 days after Your receipt of the notice.
		      5.2. If You initiate litigation against any entity by asserting a patent infringement claim (excluding declaratory judgment actions, counter-claims, and cross-claims) alleging that a Contributor Version directly or indirectly infringes any patent, then the rights granted to You by any and all Contributors for the Covered Software under Section 2.1 of this License shall terminate.
		      5.3. In the event of termination under Sections 5.1 or 5.2 above, all end user license agreements (excluding distributors and resellers) which have been validly granted by You or Your distributors under this License prior to termination shall survive termination.
		   6. Disclaimer of Warranty
		   Covered Software is provided under this License on an "as is" basis, without warranty of any kind, either expressed, implied, or statutory, including, without limitation, warranties that the Covered Software is free of defects, merchantable, fit for a particular purpose or non-infringing. The entire risk as to the quality and performance of the Covered Software is with You. Should any Covered Software prove defective in any respect, You (not any Contributor) assume the cost of any necessary servicing, repair, or correction. This disclaimer of warranty constitutes an essential part of this License. No use of any Covered Software is authorized under this License except under this disclaimer.
		   7. Limitation of Liability
		   Under no circumstances and under no legal theory, whether tort (including negligence), contract, or otherwise, shall any Contributor, or anyone who distributes Covered Software as permitted above, be liable to You for any direct, indirect, special, incidental, or consequential damages of any character including, without limitation, damages for lost profits, loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses, even if such party shall have been informed of the possibility of such damages. This limitation of liability shall not apply to liability for death or personal injury resulting from such party's negligence to the extent applicable law prohibits such limitation. Some jurisdictions do not allow the exclusion or limitation of incidental or consequential damages, so this exclusion and limitation may not apply to You.
		   8. Litigation
		   Any litigation relating to this License may be brought only in the courts of a jurisdiction where the defendant maintains its principal place of business and such litigation shall be governed by laws of that jurisdiction, without reference to its conflict-of-law provisions. Nothing in this Section shall prevent a party's ability to bring cross-claims or counter-claims.
		   9. Miscellaneous
		   This License represents the complete agreement concerning the subject matter hereof. If any provision of this License is held to be unenforceable, such provision shall be reformed only to the extent necessary to make it enforceable. Any law or regulation which provides that the language of a contract shall be construed against the drafter shall not be used to construe this License against a Contributor.
		   10. Versions of the License
		      10.1. New Versions
		      Mozilla Foundation is the license steward. Except as provided in Section 10.3, no one other than the license steward has the right to modify or publish new versions of this License. Each version will be given a distinguishing version number.
		      10.2. Effect of New Versions
		      You may distribute the Covered Software under the terms of the version of the License under which You originally received the Covered Software, or under the terms of any subsequent version published by the license steward.
		      10.3. Modified Versions
		      If you create software not governed by this License, and you want to create a new license for such software, you may create and use a modified version of this License if you rename the license and remove any references to the name of the license steward (except to note that such modified license differs from this License).
		      10.4. Distributing Source Code Form that is Incompatible With Secondary Licenses
		      If You choose to distribute Source Code Form that is Incompatible With Secondary Licenses under the terms of this version of the License, the notice described in Exhibit B of this License must be attached.<<beginOptional>> Exhibit A - Source Code Form License Notice
		This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
		If it is not possible or desirable to put the notice in a particular file, then You may include the notice in a location (such as a LICENSE file in a relevant directory) where a recipient would be likely to look for such a notice.
		You may add additional accurate notices of copyright ownership.
		Exhibit B - "Incompatible With Secondary Licenses" Notice
		This Source Code Form is "Incompatible With Secondary Licenses", as defined by the Mozilla Public License, v. 2.0.<<endOptional>>


* Authors
    * [](author)



* Other Licenses
    * **Multi-license:** MIT *OR* MPL-2.0 *OR* Python-2.0



* Project URL
    https://github.com/tqdm/tqdm


---
---

#### **treelib (1.5.5)**


* Licenses
    * Apache-2.0
        * Attribution:
        treelib - Simple to use for you.
		Python 2/3 Tree Implementation

		Copyright (C) 2011
		    Brett Alistair Kromkamp - brettkromkamp@gmail.com
		Copyright (C) 2012-2017
		    Xiaming Chen - chenxm35@gmail.com
		    and other contributors.
		All rights reserved.

		Licensed under the Apache License, Version 2.0 (the "License");
		you may not use this file except in compliance with the License.
		You may obtain a copy of the License at

		    http://www.apache.org/licenses/LICENSE-2.0

		Unless required by applicable law or agreed to in writing, software
		distributed under the License is distributed on an "AS IS" BASIS,
		WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
		See the License for the specific language governing permissions and
		limitations under the License.
    * **Multi-license:** Apache-2.0
        * Attribution:
        treelib - Simple to use for you.
		Python 2/3 Tree Implementation

		Copyright (C) 2011
		    Brett Alistair Kromkamp - brettkromkamp@gmail.com
		Copyright (C) 2012-2017
		    Xiaming Chen - chenxm35@gmail.com
		    and other contributors.
		All rights reserved.

		Licensed under the Apache License, Version 2.0 (the "License");
		you may not use this file except in compliance with the License.
		You may obtain a copy of the License at

		    http://www.apache.org/licenses/LICENSE-2.0

		Unless required by applicable law or agreed to in writing, software
		distributed under the License is distributed on an "AS IS" BASIS,
		WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
		See the License for the specific language governing permissions and
		limitations under the License. *OR* Python-2.0
        * Attribution:
        1\. This LICENSE AGREEMENT is between the Python Software Foundation ("PSF"), and the Individual or Organization ("Licensee") accessing and otherwise using this software ("Python") in source or binary form and its associated documentation.
		   2. Subject to the terms and conditions of this License Agreement, PSF hereby grants Licensee a nonexclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python alone or in any derivative version, provided, however, that PSF's License Agreement and PSF's notice of copyright, i.e., "Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006 Python Software Foundation; All Rights Reserved" are retained in Python alone or in any derivative version prepared by Licensee.
		   3. In the event Licensee prepares a derivative work that is based on or incorporates Python or any part thereof, and wants to make the derivative work available to others as provided herein, then Licensee hereby agrees to include in any such work a brief summary of the changes made to Python.
		   4. PSF is making Python available to Licensee on an "AS IS" basis. PSF MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, PSF MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
		   5. PSF SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF PYTHON FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF MODIFYING, DISTRIBUTING, OR OTHERWISE USING PYTHON, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
		   6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
		   7. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between PSF and Licensee. This License Agreement does not grant permission to use PSF trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
		   8. By copying, installing or otherwise using Python, Licensee agrees to be bound by the terms and conditions of this License Agreement.<<beginOptional>> BEOPEN.COM LICENSE AGREEMENT FOR PYTHON 2.0
		BEOPEN PYTHON OPEN SOURCE LICENSE AGREEMENT VERSION 1<<endOptional>>
		   1. This LICENSE AGREEMENT is between BeOpen.com ("BeOpen"), having an office at 160 Saratoga Avenue, Santa Clara, CA 95051, and the Individual or Organization ("Licensee") accessing and otherwise using this software in source or binary form and its associated documentation ("the Software").
		   2. Subject to the terms and conditions of this BeOpen Python License Agreement, BeOpen hereby grants Licensee a non-exclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use the Software alone or in any derivative version, provided, however, that the BeOpen Python License is retained in the Software, alone or in any derivative version prepared by Licensee.
		   3. BeOpen is making the Software available to Licensee on an "AS IS" basis. BEOPEN MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, BEOPEN MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF THE SOFTWARE WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
		   4. BEOPEN SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF THE SOFTWARE FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THE SOFTWARE, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
		   5. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
		   6. This License Agreement shall be governed by and interpreted in all respects by the law of the State of California, excluding conflict of law provisions. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between BeOpen and Licensee. This License Agreement does not grant permission to use BeOpen trademarks or trade names in a trademark sense to endorse or promote products or services of Licensee, or any third party. As an exception, the "BeOpen Python" logos available at http://www.pythonlabs.com/logos.html may be used according to the permissions granted on that web page.
		   7. By copying, installing or otherwise using the software, Licensee agrees to be bound by the terms and conditions of this License Agreement.<<beginOptional>> IMPORTANT: PLEASE READ THE FOLLOWING AGREEMENT CAREFULLY.
		BY CLICKING ON "ACCEPT" WHERE INDICATED BELOW, OR BY COPYING, INSTALLING OR OTHERWISE USING PYTHON 1.6, beta 1 SOFTWARE, YOU ARE DEEMED TO HAVE AGREED TO THE TERMS AND CONDITIONS OF THIS LICENSE AGREEMENT.<<endOptional>>
		   1. This LICENSE AGREEMENT is between the Corporation for National Research Initiatives, having an office at 1895 Preston White Drive, Reston, VA 20191 ("CNRI"), and the Individual or Organization ("Licensee") accessing and otherwise using Python 1.6, beta 1 software in source or binary form and its associated documentation, as released at the www.python.org Internet site on August 4, 2000 ("Python 1.6b1").
		   2. Subject to the terms and conditions of this License Agreement, CNRI hereby grants Licensee a non-exclusive, royalty-free, world-wide license to reproduce, analyze, test, perform and/or display publicly, prepare derivative works, distribute, and otherwise use Python 1.6b1 alone or in any derivative version, provided, however, that CNRIs License Agreement is retained in Python 1.6b1, alone or in any derivative version prepared by Licensee.
		   Alternately, in lieu of CNRIs License Agreement, Licensee may substitute the following text (omitting the quotes): "Python 1.6, beta 1, is made available subject to the terms and conditions in CNRIs License Agreement. This Agreement may be located on the Internet using the following unique, persistent identifier (known as a handle): 1895.22/1011. This Agreement may also be obtained from a proxy server on the Internet using the URL:http://hdl.handle.net/1895.22/1011".
		   3. In the event Licensee prepares a derivative work that is based on or incorporates Python 1.6b1 or any part thereof, and wants to make the derivative work available to the public as provided herein, then Licensee hereby agrees to indicate in any such work the nature of the modifications made to Python 1.6b1.
		   4. CNRI is making Python 1.6b1 available to Licensee on an "AS IS" basis. CNRI MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY OF EXAMPLE, BUT NOT LIMITATION, CNRI MAKES NO AND DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF PYTHON 1.6b1 WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
		   5. CNRI SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF THE SOFTWARE FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF USING, MODIFYING OR DISTRIBUTING PYTHON 1.6b1, OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
		   6. This License Agreement will automatically terminate upon a material breach of its terms and conditions.
		   7. This License Agreement shall be governed by and interpreted in all respects by the law of the State of Virginia, excluding conflict of law provisions. Nothing in this License Agreement shall be deemed to create any relationship of agency, partnership, or joint venture between CNRI and Licensee. This License Agreement does not grant permission to use CNRI trademarks or trade name in a trademark sense to endorse or promote products or services of Licensee, or any third party.
		   8. By clicking on the "ACCEPT" button where indicated, or by copying, installing or otherwise using Python 1.6b1, Licensee agrees to be bound by the terms and conditions of this License Agreement.
		Copyright (c) 1991 - 1995, Stichting Mathematisch Centrum Amsterdam, The Netherlands. All rights reserved.
		Permission to use, copy, modify, and distribute this software and its documentation for any purpose and without fee is hereby granted, provided that the above copyright notice appear in all copies and that both that copyright notice and this permission notice appear in supporting documentation, and that the name of Stichting Mathematisch Centrum or CWI not be used in advertising or publicity pertaining to distribution of the software without specific, written prior permission.
		STICHTING MATHEMATISCH CENTRUM DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL STICHTING MATHEMATISCH CENTRUM BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.


* Authors
    * [chenxm35@gmail.com](author)



* Other Licenses



* Project URL
    https://github.com/caesar0301/treelib


---
---

#### **urllib3 (1.25.3)**


* Licenses
    * MIT
        * Attribution:
        MIT License

		Copyright (c) 2008-2019 Andrey Petrov and contributors (see CONTRIBUTORS.txt)

		Permission is hereby granted, free of charge, to any person obtaining a copy
		of this software and associated documentation files (the "Software"), to deal
		in the Software without restriction, including without limitation the rights
		to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
		copies of the Software, and to permit persons to whom the Software is
		furnished to do so, subject to the following conditions:

		The above copyright notice and this permission notice shall be included in all
		copies or substantial portions of the Software.

		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
		SOFTWARE.



* Authors
    * [andrey.petrov@shazow.net](author)



* Other Licenses
    * Python-2.0
    * Apache-2.0



* Project URL
    https://urllib3.readthedocs.io/


---
---

#### **whichcraft (0.5.2)**


* Licenses
    * BSD-3-Clause
        * Attribution:
        Copyright (c) 2015-2016, Daniel Roy Greenfeld
		All rights reserved.

		Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

		\* Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

		\* Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

		\* Neither the name of whichcraft nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

		THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.



* Authors
    * [pydanny@gmail.com](author)



* Other Licenses



* Project URL
    https://github.com/pydanny/whichcraft


---
---






***Deep dependencies not included.  Enable this in FOSSA to include deeper data.***



***Full license list not included.  Enable this in FOSSA to include licenses.***



[FOSSA]: # (Do not touch the comments below)

[FOSSA]: # (==depsig=e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855==)
